@@ -1435,7 +1435,7 @@ static void give_activation_power(object_type *o_ptr)
 
 static void get_random_name(char *return_name, byte tval, int power)
 {
-	if ((tval == TV_AMULET) || (tval == TV_RING))
+	if ((tval == TV_AMULET) || (tval == TV_RING) || (tval == TV_LITE))
 	{
 		get_table_name(return_name);
 	}
@@ -1556,6 +1556,7 @@ bool create_artifact(object_type *o_ptr, bool a_scroll)
 				artifact_bias = BIAS_WARRIOR;
 				break;
 			case CLASS_MAGE:
+			case CLASS_ELEMENTALIST:
 				artifact_bias = BIAS_MAGE;
 				break;
 			case CLASS_PRIEST:
@@ -1679,7 +1680,13 @@ bool create_artifact(object_type *o_ptr, bool a_scroll)
 
 	if (a_cursed) curse_artifact(o_ptr);
 
-	if (!a_cursed &&
+	if (o_ptr->tval == TV_LITE && o_ptr->sval == SV_LITE_FEANOR)
+	{
+		artifact_bias = 0;
+		o_ptr->xtra2 = 0;
+		give_activation_power(o_ptr);
+	}
+	else if (!a_cursed &&
 	    (randint1((o_ptr->tval >= TV_BOOTS)
 	    ? ACTIVATION_CHANCE * 2 : ACTIVATION_CHANCE) == 1))
 	{
@@ -1708,7 +1715,7 @@ bool create_artifact(object_type *o_ptr, bool a_scroll)
 		char dummy_name[80];
 		strcpy(dummy_name, "");
 		(void)identify_fully_aux(o_ptr, TRUE);
-		o_ptr->ident |= IDENT_STOREB; /* This will be used later on... */
+		o_ptr->ident |= IDENT_STORE; /* This will be used later on... */
 #ifdef JP
 		if (!(get_string("ΥƥեȤ򲿤̾դޤ", dummy_name, 80)))
 #else
@@ -2081,6 +2088,7 @@ bool activate_random_artifact(object_type * o_ptr)
 #else
 			msg_print("You launch a rocket!");
 #endif
+			sound(SOUND_ROCKET);
 			fire_ball(GF_ROCKET, dir, 120 + plev, 2);
 			o_ptr->timeout = 400;
 			break;
@@ -2118,6 +2126,7 @@ bool activate_random_artifact(object_type * o_ptr)
 #else
 			msg_print("You breathe the elements.");
 #endif
+			sound(SOUND_BREATH);
 			fire_ball(GF_MISSILE, dir, 300, -4);
 			o_ptr->timeout = 500;
 			break;
@@ -2216,7 +2225,7 @@ bool activate_random_artifact(object_type * o_ptr)
 			if (banish_evil(100))
 			{
 #ifdef JP
-				msg_print("ƥեȤϤٰǤݤ");
+				msg_print("ƥեȤϤٰǤʧä");
 #else
 				msg_print("The power of the artifact banishes evil!");
 #endif
@@ -2654,7 +2663,7 @@ bool activate_random_artifact(object_type * o_ptr)
 #endif
 			detect_all(DETECT_RAD_DEFAULT);
 			probing();
-			identify_fully(FALSE);
+			(void)identify_fully();
 			o_ptr->timeout = 1000;
 			break;
 		}
@@ -2666,14 +2675,14 @@ bool activate_random_artifact(object_type * o_ptr)
 #else
 			msg_print("It glows yellow...");
 #endif
-			identify_fully(FALSE);
+			(void)identify_fully();
 			o_ptr->timeout = 750;
 			break;
 		}
 
 		case ACT_ID_PLAIN:
 		{
-			if (!ident_spell(FALSE)) return FALSE;
+			if (!ident_spell()) return FALSE;
 			o_ptr->timeout = 10;
 			break;
 		}
@@ -3095,7 +3104,7 @@ bool create_nazgul_ring(object_type *o_ptr)
 	/* give it some plusses... */
 	o_ptr->pval = (one_in_(5)) ? 2 : 1;
 	o_ptr->to_a = 0;
-	o_ptr->to_h = randint0(5) + 5;
+	o_ptr->to_h = randint0(3) + 10;
 	o_ptr->to_d = o_ptr->to_h;
 
 	/* Just to be sure */
