@@ -23,28 +23,19 @@ void have_nightmare(int r_idx)
 	cptr desc = r_name + r_ptr->name;
 
 
-#ifdef JP
-	if (FALSE)
-#else
+	/* Describe it */
+#ifndef JP
 	if (!(r_ptr->flags1 & RF1_UNIQUE))
-#endif
-
-	{
-		/* Describe it */
 		sprintf(m_name, "%s %s", (is_a_vowel(desc[0]) ? "an" : "a"), desc);
-
-		if (r_ptr->flags1 & RF1_FRIENDS)
-		{
-			power /= 2;
-		}
-	}
 	else
-	{
-		/* Describe it */
+#endif
 		sprintf(m_name, "%s", desc);
 
-		power *= 2;
+	if (!(r_ptr->flags1 & RF1_UNIQUE))
+	{
+		if (r_ptr->flags1 & RF1_FRIENDS) power /= 2;
 	}
+	else power *= 2;
 
 	if (saving_throw(p_ptr->skill_sav * 100 / power))
 	{
@@ -456,9 +447,6 @@ void check_failed_random_quest(void)
 /* hack as in leave_store in store.c */
 static bool leave_bldg = FALSE;
 
-/* remember building location */
-static int building_loc = 0;
-
 static bool reinit_wilderness = FALSE;
 
 static bool is_owner(building_type *bldg)
@@ -746,7 +734,6 @@ msg_print("ʤϥ꡼ʤꡢФ餯δֱɸˤҤä");
 			}
 			else
 			{
-				p_ptr->leftbldg = TRUE;
 				p_ptr->inside_arena = TRUE;
 				p_ptr->exit_bldg = FALSE;
 				reset_tim_flags();
@@ -1342,13 +1329,21 @@ static bool gamble_comm(int cmd)
  */
 static bool inn_comm(int cmd)
 {
-	s32b dawnval;
-
 	switch (cmd)
 	{
 		case BACT_FOOD: /* Buy food & drink */
+			if (p_ptr->food >= PY_FOOD_FULL)
+			{
 #ifdef JP
-msg_print("СƥϤ餫οʪȥӡ򤯤줿");
+				msg_print("ʢ");
+#else
+				msg_print("You are full now.");
+#endif
+				return FALSE;
+			}
+
+#ifdef JP
+			msg_print("СƥϤ餫οʪȥӡ򤯤줿");
 #else
 			msg_print("The barkeep gives you some gruel and a beer.");
 #endif
@@ -1358,93 +1353,95 @@ msg_print("СƥϤ餫οʪȥӡ򤯤줿");
 			break;
 
 		case BACT_REST: /* Rest for the night */
-			dawnval = ((turn % (10L * TOWN_DAWN)));
-			if (dawnval > 50000)
-			{  /* nighttime */
-				if ((p_ptr->poisoned) || (p_ptr->cut))
-				{
-#ifdef JP
-msg_print("ʤɬפʤΤǤϤʤżԤǤ");
-#else
-					msg_print("You need a healer, not a room.");
-#endif
-
-					msg_print(NULL);
-#ifdef JP
-msg_print("ߤޤ󡢤Ǥ⤦ï˻ʤ㺤ޤǡ");
-#else
-					msg_print("Sorry, but don't want anyone dying in here.");
-#endif
-
-					return (FALSE);
-				}
-				else
-				{
-					turn = ((turn / 50000) + 1) * 50000;
-					p_ptr->chp = p_ptr->mhp;
-
-					if (ironman_nightmare)
-					{
-#ifdef JP
-msg_print("̲˽ȶʤ褮ä");
-#else
-						msg_print("Horrible visions flit through your mind as you sleep.");
-#endif
-
-
-						/* Pick a nightmare */
-						get_mon_num_prep(get_nightmare, NULL);
-
-						/* Have some nightmares */
-						while (1)
-						{
-							have_nightmare(get_mon_num(MAX_DEPTH));
-
-							if (!one_in_(3)) break;
-						}
-
-						/* Remove the monster restriction */
-						get_mon_num_prep(NULL, NULL);
-
-#ifdef JP
-msg_print("ʤ䶫ܤФޤ");
-#else
-						msg_print("You awake screaming.");
-#endif
-
-					}
-					else
-					{
-						set_blind(0);
-						set_confused(0);
-						p_ptr->stun = 0;
-						p_ptr->chp = p_ptr->mhp;
-						p_ptr->csp = p_ptr->msp;
-
-#ifdef JP
-msg_print("ʤϥեå夷ܳФᡢޤ");
-#else
-						msg_print("You awake refreshed for the new day.");
-#endif
-
-					}
-
-					msg_print(NULL);
-					p_ptr->leftbldg = TRUE;
-				}
-			}
-			else
+			if ((p_ptr->poisoned) || (p_ptr->cut))
 			{
 #ifdef JP
-msg_print("ѲǽǤ");
+				msg_print("ʤɬפʤΤǤϤʤżԤǤ");
 #else
-				msg_print("The rooms are available only at night.");
+				msg_print("You need a healer, not a room.");
 #endif
 
 				msg_print(NULL);
+#ifdef JP
+				msg_print("ߤޤ󡢤Ǥ⤦ï˻ʤ㺤ޤǡ");
+#else
+				msg_print("Sorry, but don't want anyone dying in here.");
+#endif
+
 				return (FALSE);
 			}
+			else
+			{
+				int prev_day, prev_hour, prev_min;
+
+				extract_day_hour_min(&prev_day, &prev_hour, &prev_min);
+
+				turn = ((turn / (10L * TOWN_DAWN / 2)) + 1) * (10L * TOWN_DAWN / 2);
+				p_ptr->chp = p_ptr->mhp;
+
+				if (take_notes)
+				{
+					if ((prev_hour >= 18) && (prev_hour <= 23)) add_note(" ", 'D');
+				}
+
+				if (ironman_nightmare)
+				{
+#ifdef JP
+					msg_print("̲˽ȶʤ褮ä");
+#else
+					msg_print("Horrible visions flit through your mind as you sleep.");
+#endif
+
+					/* Pick a nightmare */
+					get_mon_num_prep(get_nightmare, NULL);
+
+					/* Have some nightmares */
+					while (1)
+					{
+						have_nightmare(get_mon_num(MAX_DEPTH));
+
+						if (!one_in_(3)) break;
+					}
+
+					/* Remove the monster restriction */
+					get_mon_num_prep(NULL, NULL);
+
+#ifdef JP
+					msg_print("ʤ䶫ܤФޤ");
+#else
+					msg_print("You awake screaming.");
+#endif
+				}
+				else
+				{
+					set_blind(0);
+					set_confused(0);
+					p_ptr->stun = 0;
+					p_ptr->chp = p_ptr->mhp;
+					p_ptr->csp = p_ptr->msp;
+
+					if ((prev_hour >= 6) && (prev_hour <= 17))
+					{
+#ifdef JP
+						msg_print("ʤϥեå夷ܳФᡢͼޤ");
+#else
+						msg_print("You awake refreshed for the evening.");
+#endif
+					}
+					else
+					{
+#ifdef JP
+						msg_print("ʤϥեå夷ܳФᡢޤ");
+#else
+						msg_print("You awake refreshed for the new day.");
+#endif
+					}
+				}
+
+				msg_print(NULL);
+			}
 			break;
+
 		case BACT_RUMORS: /* Listen for rumors */
 			{
 				char Rumor[1024];
@@ -1539,17 +1536,16 @@ sprintf(tmp_str, "Ⱦ (: %d )", quest[questnum].level);
  */
 static void castle_quest(void)
 {
-	int             q_index = 0;
 	monster_race    *r_ptr;
 	quest_type      *q_ptr;
 	cptr            name;
 
+	/* Current quest of the building */
+	int             q_index = cave[py][px].special;
+
 
 	clear_bldg(7, 18);
 
-	/* Current quest of the building */
-	q_index = cave[py][px].special;
-
 	/* Is there a quest available at the building? */
 	if (!q_index)
 	{
@@ -1801,16 +1797,8 @@ static void list_weapon(object_type *o_ptr, int row, int col)
 	int maxdam, mindam;
 	int dambonus;
 
-#ifdef JP
-	/* Modification to the critical multiplyer */
-	int mult_crit = 120 / (o_ptr->dd * (o_ptr->ds + 1));
-	
-	if (mult_crit > 20) mult_crit = 20;
-	if (mult_crit < 10) mult_crit = 10;
-#endif
-
 	/* Print the weapon name */
-	object_desc(o_name, o_ptr, TRUE, 0);
+	object_desc(o_name, o_ptr, OD_NAME_ONLY);
 	c_put_str(TERM_YELLOW, o_name, row, col);
 
 	/* Print the player's number of blows */
@@ -2052,7 +2040,7 @@ static bool compare_weapons(void)
 /*
  * Forge ego item
  */
-static bool forge_ego_item()
+static bool forge_ego_item(void)
 {
 	int item;
 	int cost;
@@ -2359,7 +2347,7 @@ static bool enchant_item(int cost, int to_hit, int to_dam, int to_ac)
 	/* Check if the player has enough money */
 	if (p_ptr->au < (cost * o_ptr->number))
 	{
-		object_desc(tmp_str, o_ptr, TRUE, 0);
+		object_desc(tmp_str, o_ptr, OD_NAME_ONLY);
 #ifdef JP
 		msg_format("%sɤΥɤޤ", tmp_str);
 #else
@@ -2425,11 +2413,11 @@ static bool enchant_item(int cost, int to_hit, int to_dam, int to_ac)
 	}
 	else
 	{
-		object_desc(tmp_str, o_ptr, TRUE, 1);
+		object_desc(tmp_str, o_ptr, OD_NAME_AND_ENCHANT);
 #ifdef JP
-		msg_format("%d %sɤޤ", cost * o_ptr->number, tmp_str );
+		msg_format("%d %s˲ɤޤ", cost * o_ptr->number, tmp_str);
 #else
-		msg_format("Improved %s for %d gold.", tmp_str, cost * o_ptr->number);
+		msg_format("Improved into %s for %d gold.", tmp_str, cost * o_ptr->number);
 #endif
 		msg_print(NULL);
 
@@ -2530,7 +2518,7 @@ s = "ϤŶ٤ƥबʤ";
 			identify_item(o_ptr);
 
 			/* Description */
-			object_desc(tmp_str, o_ptr, TRUE, 3);
+			object_desc(tmp_str, o_ptr, 0);
 
 #ifdef JP
 			msg_format("%s Ǥ", tmp_str);
@@ -2538,6 +2526,9 @@ s = "ϤŶ٤ƥबʤ";
 			msg_format("You have: %s.", tmp_str);
 #endif
 
+			/* Auto-inscription */
+			autopick_alter_item(item, FALSE);
+
 			/* Update the gold display */
 			building_prt_gold();
 		}
@@ -2622,7 +2613,7 @@ s = "ϤŶ٤ƥबʤ";
 	/* Check if the player has enough money */
 	if (p_ptr->au < price)
 	{
-		object_desc(tmp_str, o_ptr, TRUE, 0);
+		object_desc(tmp_str, o_ptr, OD_NAME_ONLY);
 #ifdef JP
 		msg_format("%sƽŶˤϡ%d ɬפǤ", tmp_str,price );
 #else
@@ -2679,7 +2670,7 @@ s = "ϤŶ٤ƥबʤ";
 	}
 
 	/* Give feedback */
-	object_desc(tmp_str, o_ptr, TRUE, 3);
+	object_desc(tmp_str, o_ptr, 0);
 #ifdef JP
 	msg_format("%s%d ǺƽŶޤ", tmp_str, price);
 #else
@@ -2734,7 +2725,7 @@ static void building_recharge_all(void)
 	for ( i = 0; i < INVEN_PACK; i++)
 	{
 		o_ptr = &inventory[i];
-				
+
 		/* skip non magic device */
 		if (o_ptr->tval < TV_STAFF || o_ptr->tval > TV_ROD) continue;
 
@@ -2813,12 +2804,18 @@ static void building_recharge_all(void)
 	{
 		o_ptr = &inventory[i];
 		k_ptr = &k_info[o_ptr->k_idx];
-				
+
 		/* skip non magic device */
 		if (o_ptr->tval < TV_STAFF || o_ptr->tval > TV_ROD) continue;
 
 		/* Identify it */
-		if (!object_known_p(o_ptr)) identify_item(o_ptr);
+		if (!object_known_p(o_ptr))
+		{
+			identify_item(o_ptr);
+
+			/* Auto-inscription */
+			autopick_alter_item(i, FALSE);
+		}
 
 		/* Recharge */
 		switch (o_ptr->tval)
@@ -2910,7 +2907,7 @@ static void bldg_process_command(building_type *bldg, int i)
 			/* Do nothing */
 			break;
 		case BACT_RESEARCH_ITEM:
-			paid = identify_fully(FALSE);
+			paid = identify_fully();
 			break;
 		case BACT_TOWN_HISTORY:
 			town_history();
@@ -2924,7 +2921,7 @@ static void bldg_process_command(building_type *bldg, int i)
 		case BACT_KING_LEGENDS:
 		case BACT_ARENA_LEGENDS:
 		case BACT_LEGENDS:
-			show_highclass(building_loc);
+			show_highclass();
 			break;
 		case BACT_POSTER:
 		case BACT_ARENA_RULES:
@@ -3112,8 +3109,7 @@ void do_cmd_quest(void)
 		leave_quest_check();
 
 		p_ptr->inside_quest = cave[py][px].special;
-		if(quest[leaving_quest].type != QUEST_TYPE_RANDOM) dun_level = 1;
-		p_ptr->leftbldg = TRUE;
+		if (quest[leaving_quest].type != QUEST_TYPE_RANDOM) dun_level = 1;
 		p_ptr->leaving = TRUE;
 	}
 }
@@ -3141,7 +3137,6 @@ void do_cmd_bldg(void)
 	}
 
 	which = (cave[py][px].feat - FEAT_BLDG_HEAD);
-	building_loc = which;
 
 	bldg = &building[which];
 
