@@ -66,7 +66,7 @@ static const char *spell_tips[MAX_REALM][32] =
 		"ϾˤȤϥ󥸥κǿء󥸥ˤȤϾؤȰư롣",
 
 		"ɤϤƾˤ롣",
-		"/ˡνŶ䤹ŶΥåɤνŶ֤򸺤餹",
+		"å/ɤνŶ䤹ŶΥåɤνŶ֤򸺤餹",
 		"դϷΤ롣",
 		"ƥ1ļ̤롣٥뤬⤤ȥƥǽϤΤ뤳ȤǤ롣",
 		"֡ƥѥǽϤ롣",
@@ -264,7 +264,7 @@ byte get_modified_smana(magic_type *s_ptr)
 static int get_spell(int *sn, cptr prompt, int sval, bool known, int use_realm)
 {
 	int         i;
-	int         spell = -1;
+	int         spell;
 	int         num = 0;
 	int         ask;
 	byte        spells[32];
@@ -492,7 +492,7 @@ static int get_spell(int *sn, cptr prompt, int sval, bool known, int use_realm)
  */
 void do_cmd_browse(void)
 {
-	int		item, sval, use_realm = 0, j, line;
+	int		item, sval, use_realm, j, line;
 	int		spell = -1;
 	int		num = 0;
 
@@ -500,7 +500,6 @@ void do_cmd_browse(void)
 	char		temp[62 * 4];
 
 	object_type	*o_ptr;
-	magic_type	*s_ptr;
 
 	cptr q, s;
 
@@ -606,8 +605,6 @@ void do_cmd_browse(void)
 		Term_erase(14, 16, 255);
 		Term_erase(14, 15, 255);
 
-		s_ptr = &mp_ptr->info[use_realm - 1][spell];
-
 		roff_to_buf(spell_tips[use_realm - 1][spell], 62, temp, sizeof(temp));
 		for(j = 0, line = 15; temp[j]; j += (1 + strlen(&temp[j])))
 		{
@@ -814,7 +811,7 @@ void do_cmd_study(void)
 	}
 
 	/* Add the spell to the known list */
-	spell_order[i++] = spell;
+	spell_order[i] = spell;
 
 	/* Mention the result */
 #ifdef JP
@@ -1021,7 +1018,7 @@ static bool cast_life_spell(int spell)
 		wiz_lite();
 		break;
 	case 29: /* Holy Vision */
-		return identify_fully(FALSE);
+		return identify_fully();
 	case 30: /* Healing True */
 		(void)hp_player(1000);
 		(void)set_stun(0);
@@ -1126,14 +1123,8 @@ static bool cast_sorcery_spell(int spell)
 		map_area(DETECT_RAD_MAP);
 		break;
 	case 13: /* Identify */
-		if(plev < 35)
-		{
-			return ident_spell(FALSE);
-		}
-		else
-		{
-			return identify_fully(FALSE);
-		}
+		if (plev < 35) return ident_spell();
+		else return identify_fully();
 	case 14: /* Sense Minds */
 		(void)set_tim_esp(p_ptr->tim_esp + randint1(30) + 25);
 		break;
@@ -1165,6 +1156,7 @@ static bool cast_sorcery_spell(int spell)
 #else
 		msg_print("You launch a rocket!");
 #endif
+		sound(SOUND_ROCKET);
 		fire_ball(GF_ROCKET, dir, (120 + plev * 2), 2);
 		break;
 	case 19: /* Genocide */
@@ -1403,7 +1395,7 @@ static bool cast_musou_spell(int spell)
 		break;
 	case 16: /* Whirlwind Attack */
 		{
-			int y = 0, x = 0;
+			int y, x;
 			cave_type       *c_ptr;
 			monster_type    *m_ptr;
 
@@ -1791,7 +1783,6 @@ void do_cmd_cast(void)
 		if (j_ptr->tval)
 		{
 			int thits = p_ptr->num_fire;
-			int tmul = bow_tmul(j_ptr->sval);
 
 			energy_use = bow_energy(j_ptr->sval);
 			energy_use = (energy_use * 100 / thits);
