@@ -107,7 +107,6 @@ static void sense_inventory(void)
 	byte        feel;
 	object_type *o_ptr;
 	char        o_name[MAX_NLEN];
-	int idx;
 
 	/*** Check for "sensing" ***/
 
@@ -248,7 +247,7 @@ static void sense_inventory(void)
 		if (disturb_minor) disturb(0, 0);
 
 		/* Get an object description */
-		object_desc(o_name, o_ptr, FALSE, 0);
+		object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 		/* Message (equipment) */
 		if (i >= INVEN_WIELD)
@@ -285,10 +284,7 @@ static void sense_inventory(void)
 		o_ptr->feeling = feel;
 
 		/* Auto-inscription/destroy */
-		idx = is_autopick(o_ptr);
-		auto_inscribe_item(i, idx);
-		if (destroy_feeling)
-			auto_destroy_item(i, idx);
+		autopick_alter_item(i, destroy_feeling);
 
 		/* Combine / Reorder the pack (later) */
 		p_ptr->notice |= (PN_COMBINE | PN_REORDER);
@@ -306,7 +302,6 @@ static void sense_magic(void)
 	byte        feel;
 	object_type *o_ptr;
 	char        o_name[MAX_NLEN];
-	int idx;
 
 	/*** Check for "sensing" ***/
 
@@ -433,7 +428,7 @@ static void sense_magic(void)
 		if (disturb_minor) disturb(0, 0);
 
 		/* Get an object description */
-		object_desc(o_name, o_ptr, FALSE, 0);
+		object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 		/* Message (equipment) */
 		if (i >= INVEN_WIELD)
@@ -470,10 +465,7 @@ static void sense_magic(void)
 		o_ptr->feeling = feel;
 
 		/* Auto-inscription/destroy */
-		idx = is_autopick(o_ptr);
-		auto_inscribe_item(i, idx);
-		if (destroy_feeling)
-			auto_destroy_item(i, idx);
+		autopick_alter_item(i, destroy_feeling);
 
 		/* Combine / Reorder the pack (later) */
 		p_ptr->notice |= (PN_COMBINE | PN_REORDER);
@@ -569,50 +561,6 @@ msg_format("%d ˥ƥݡȤޤ", command_arg);
 }
 
 
-static void wreck_the_pattern(void)
-{
-	int to_ruin, r_y, r_x;
-
-	if (cave[py][px].feat == FEAT_PATTERN_XTRA2)
-	{
-		/* Ruined already */
-		return;
-	}
-
-#ifdef JP
-msg_print("ѥǱƤޤä");
-msg_print("ä");
-#else
-	msg_print("You bleed on the Pattern!");
-	msg_print("Something terrible happens!");
-#endif
-
-
-	if (!p_ptr->invuln)
-#ifdef JP
-take_hit(damroll(10, 8), "ѥ»");
-#else
-		take_hit(damroll(10, 8), "corrupting the Pattern");
-#endif
-
-
-	to_ruin = randint1(45) + 35;
-
-	while (to_ruin--)
-	{
-		scatter(&r_y, &r_x, py, px, 4, 0);
-
-		if ((cave[r_y][r_x].feat >= FEAT_PATTERN_START) &&
-		    (cave[r_y][r_x].feat < FEAT_PATTERN_XTRA2))
-		{
-			cave_set_feat(r_y, r_x, FEAT_PATTERN_XTRA2);
-		}
-	}
-
-	cave_set_feat(py, px, FEAT_PATTERN_XTRA2);
-}
-
-
 /* Returns TRUE if we are on the Pattern... */
 static bool pattern_effect(void)
 {
@@ -891,6 +839,12 @@ void leave_quest_check(void)
 }
 
 
+static bool item_tester_hook_psychometry(object_type *o_ptr)
+{
+	return (!object_known_p(o_ptr) && 
+		((o_ptr->feeling == FEEL_NONE) || (o_ptr->feeling == FEEL_UNCURSED)));
+}
+
 /*
  * Forcibly pseudo-identify an object in the inventory
  * (or on the floor)
@@ -911,7 +865,8 @@ bool psychometry(void)
 	byte            feel;
 	cptr            q, s;
 	bool            okay = FALSE;
-	int             idx;
+
+	item_tester_hook = item_tester_hook_psychometry;
 
 	/* Get an item */
 #ifdef JP
@@ -951,7 +906,7 @@ bool psychometry(void)
 	feel = value_check_aux1(o_ptr);
 
 	/* Get an object description */
-	object_desc(o_name, o_ptr, FALSE, 0);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 	/* Skip non-feelings */
 	if (!feel)
@@ -979,6 +934,9 @@ bool psychometry(void)
 	/* "Inscribe" it */
 	o_ptr->feeling = feel;
 
+	/* Player touches it */
+	o_ptr->marked |= OM_TOUCHED;
+
 	/* Combine / Reorder the pack (later) */
 	p_ptr->notice |= (PN_COMBINE | PN_REORDER);
 
@@ -1014,10 +972,7 @@ bool psychometry(void)
 	}
 
 	/* Auto-inscription/destroy */
-	idx = is_autopick(o_ptr);
-	auto_inscribe_item(item, idx);
-	if (okay && destroy_feeling)
-		auto_destroy_item(item, idx);
+	autopick_alter_item(item, (bool)(okay && destroy_feeling));
 
 	/* Something happened */
 	return (TRUE);
@@ -1033,7 +988,7 @@ static void recharged_notice_aux(object_type *o_ptr)
 	char o_name[MAX_NLEN];
 
 	/* Describe (briefly) */
-	object_desc(o_name, o_ptr, FALSE, 0);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 	/* Notify the player */
 #ifdef JP
@@ -1048,6 +1003,7 @@ static void recharged_notice_aux(object_type *o_ptr)
 	disturb(0, 0);
 }
 
+
 static void recharged_notice(object_type *o_ptr)
 {
 	cptr s;
@@ -1056,7 +1012,7 @@ static void recharged_notice(object_type *o_ptr)
 	if (!o_ptr->inscription) return;
 
 	/* Find a '%' */
-	s = strchr(quark_str(o_ptr->inscription), '%');
+	s = my_strchr(quark_str(o_ptr->inscription), '%');
 
 	if (s)
 	{
@@ -1068,7 +1024,7 @@ static void recharged_notice(object_type *o_ptr)
 	}
 
 	/* Find a '!' */
-	s = strchr(quark_str(o_ptr->inscription), '!');
+	s = my_strchr(quark_str(o_ptr->inscription), '!');
 
 	/* Process notification request. */
 	while (s)
@@ -1084,11 +1040,245 @@ static void recharged_notice(object_type *o_ptr)
 		}
 
 		/* Keep looking for '!'s */
-		s = strchr(s + 1, '!');
+		s = my_strchr(s + 1, '!');
 	}
 }
 
 
+/*
+ * Count number of adjacent monsters
+ */
+static int get_monster_crowd_number(int m_idx)
+{
+	monster_type *m_ptr = &m_list[m_idx];
+	int my = m_ptr->fy;
+	int mx = m_ptr->fx;
+	int i;
+	int count = 0;
+
+	for (i = 0; i < 7; i++)
+	{
+		int ay = my + ddy_ddd[i];
+		int ax = mx + ddx_ddd[i];
+
+		if (!in_bounds(ay, ax)) continue;
+
+		/* Count number of monsters */
+		if (cave[ay][ax].m_idx > 0) count++;
+ 	}
+
+	return count;
+}
+
+
+
+/*
+ * Dungeon rating is no longer linear
+ */
+#define RATING_BOOST(delta) (delta * delta + 50 * delta)
+
+/*
+ * Examine all monsters and unidentified objects,
+ * and get the feeling of current dungeon floor
+ */
+byte get_dungeon_feeling(void)
+{
+	const int base = 10;
+	int rating = 0;
+	int i;
+
+	/* Hack -- no feeling in the town */
+	if (!dun_level) return 0;
+
+	/* Examine each monster */
+	for (i = 1; i < m_max; i++)
+	{
+		monster_type *m_ptr = &m_list[i];
+		monster_race *r_ptr;
+		int delta = 0;
+
+		/* Skip dead monsters */
+		if (!m_ptr->r_idx) continue;
+
+		/* Ignore pet */
+		if (is_pet(m_ptr)) continue;
+
+		r_ptr = &r_info[m_ptr->r_idx];
+
+		/* Unique monsters */
+		if (r_ptr->flags1 & (RF1_UNIQUE))
+		{
+			/* Nearly out-of-depth unique monsters */
+			if (r_ptr->level + 10 > dun_level)
+			{
+				/* Boost rating by twice delta-depth */
+				delta += (r_ptr->level + 10 - dun_level) * 2 * base;
+			}
+		}
+		else
+		{
+			/* Out-of-depth monsters */
+			if (r_ptr->level > dun_level)
+			{
+				/* Boost rating by delta-depth */
+				delta += (r_ptr->level - dun_level) * base;
+			}
+		}
+
+		/* Unusually crowded monsters get a little bit of rating boost */
+		if (r_ptr->flags1 & RF1_FRIENDS)
+		{
+			if (5 <= get_monster_crowd_number(i)) delta += 1;
+		}
+		else
+		{
+			if (2 <= get_monster_crowd_number(i)) delta += 1;
+		}
+
+
+		rating += RATING_BOOST(delta);
+	}
+
+	/* Examine each unidentified object */
+	for (i = 1; i < o_max; i++)
+	{
+		object_type *o_ptr = &o_list[i];
+		object_kind *k_ptr = &k_info[o_ptr->k_idx];
+		int delta = 0;
+
+		/* Skip dead objects */
+		if (!o_ptr->k_idx) continue;
+
+		/* Skip known objects */
+		if (object_known_p(o_ptr))
+		{
+			/* Touched? */
+			if (o_ptr->marked & OM_TOUCHED) continue;
+		}
+
+		/* Skip pseudo-known objects */
+		if (o_ptr->ident & IDENT_SENSE) continue;
+
+		/* Ego objects */
+		if (ego_item_p(o_ptr))
+		{
+			ego_item_type *e_ptr = &e_info[o_ptr->name2];
+
+			delta += e_ptr->rating * base;
+		}
+
+		/* Fixed artifacts */
+		if (artifact_p(o_ptr))
+		{
+			s32b cost;
+
+			/* Special feeling */
+			if (!preserve_mode) return 1;
+
+			cost = object_value_real(o_ptr);
+
+			delta += 10 * base;
+			if (cost > 50000L) delta += 10 * base;
+		}
+
+		/* Random artifacts */
+		if (o_ptr->art_name) delta += 40 * base;
+
+		if (o_ptr->tval == TV_DRAG_ARMOR) delta += 30 * base;
+		if (o_ptr->tval == TV_SHIELD &&
+		    o_ptr->sval == SV_DRAGON_SHIELD) delta += 5 * base;
+		if (o_ptr->tval == TV_GLOVES &&
+		    o_ptr->sval == SV_SET_OF_DRAGON_GLOVES) delta += 5 * base;
+		if (o_ptr->tval == TV_BOOTS &&
+		    o_ptr->sval == SV_PAIR_OF_DRAGON_BOOTS) delta += 5 * base;
+		if (o_ptr->tval == TV_HELM &&
+		    o_ptr->sval == SV_DRAGON_HELM) delta += 5 * base;
+		if (o_ptr->tval == TV_RING &&
+		    o_ptr->sval == SV_RING_SPEED &&
+		    !cursed_p(o_ptr)) delta += 25 * base;
+		if (o_ptr->tval == TV_RING &&
+		    o_ptr->sval == SV_RING_LORDLY) delta += 5 * base;
+		if (o_ptr->tval == TV_AMULET &&
+		    o_ptr->sval == SV_AMULET_THE_MAGI) delta += 25 * base;
+		if (o_ptr->tval == TV_AMULET &&
+		    o_ptr->sval == SV_AMULET_THE_HERO) delta += 25 * base;
+
+		/* Out-of-depth objects */
+		if (!cursed_p(o_ptr) && !broken_p(o_ptr) &&
+		    k_ptr->level > dun_level)
+		{
+			/* Rating increase */
+			delta += (k_ptr->level - dun_level) * base;
+		}
+
+		rating += RATING_BOOST(delta);
+	}
+
+
+	if (rating > RATING_BOOST(1000)) return 2;
+	if (rating > RATING_BOOST(800)) return 3;
+	if (rating > RATING_BOOST(600)) return 4;
+	if (rating > RATING_BOOST(400)) return 5;
+	if (rating > RATING_BOOST(300)) return 6;
+	if (rating > RATING_BOOST(200)) return 7;
+	if (rating > RATING_BOOST(100)) return 8;
+	if (rating > RATING_BOOST(0)) return 9;
+
+	return 10;
+}
+
+
+/*
+ * Update dungeon feeling, and announce it if changed
+ */
+static void update_dungeon_feeling(void)
+{
+	byte new_feeling;
+	int quest_num;
+	int delay;
+
+	/* No feeling on the surface */
+	if (!dun_level) return;
+
+	/* Extract delay time */
+	delay = MAX(10, 150 - p_ptr->skill_fos) * (150 - dun_level) * 10 / 100;
+
+ 	/* Not yet felt anything */
+	if (turn < p_ptr->feeling_turn + delay && !cheat_xtra) return;
+
+	/* Extract quest number (if any) */
+	quest_num = quest_number(dun_level);
+
+	/* No feeling in a quest */
+	if (quest_num &&
+	    (((quest_num < MIN_RANDOM_QUEST) || (quest_num > MAX_RANDOM_QUEST)) &&
+	     !((quest_num == QUEST_OBERON) || (quest_num == QUEST_SERPENT) ||
+	       !(quest[quest_num].flags & QUEST_FLAG_PRESET)))) return;
+
+
+	/* Get new dungeon feeling */
+	new_feeling = get_dungeon_feeling();
+
+	/* Remember last time updated */
+	p_ptr->feeling_turn = turn;
+
+	/* No change */
+	if (p_ptr->feeling == new_feeling) return;
+
+	/* Dungeon feeling is changed */
+	p_ptr->feeling = new_feeling;
+
+	/* Announce feeling */
+	do_cmd_feeling();
+
+	/* Update the level indicator */
+	p_ptr->redraw |= (PR_DEPTH);
+
+	/* Disturb */
+	if (disturb_minor) disturb(0, 0);
+}
+
+
 /*
  * Handle certain things once every 10 game turns
  */
@@ -1104,9 +1294,16 @@ static void process_world(void)
 	int temp;
 	object_kind *k_ptr;
 
-	/* Announce the level feeling */
-	if ((turn - old_turn == 1000) && (dun_level)) do_cmd_feeling();
+	int day, hour, min, prev_min;
 
+#define __LEN (10L * TOWN_DAWN)
+	s32b tick = (turn % __LEN) + (__LEN / 4);
+
+	extract_day_hour_min(&day, &hour, &min);
+	prev_min = (1440 * (tick - 10L) / __LEN) % 60;
+
+	/* Update dungeon feeling, and announce it if changed */
+	update_dungeon_feeling();
 
 	/* Every 10 game turns */
 	if (turn % 10) return;
@@ -1351,7 +1548,7 @@ take_hit(1, "");
 			char ouch[80];
 
 			/* Get an object description */
-			object_desc(o_name, o_ptr, FALSE, 0);
+			object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 #ifdef JP
 msg_format("%sʤΥǥåɤΤƤǤ", o_name);
@@ -1363,7 +1560,7 @@ msg_format("%sʤΥǥåɤΤƤǤ", o_name);
 			cave_no_regen = TRUE;
 
 			/* Get an object description */
-			object_desc(o_name, o_ptr, TRUE, 0);
+			object_desc(o_name, o_ptr, OD_NAME_ONLY);
 
 #ifdef JP
 sprintf(ouch, "%s᡼", o_name);
@@ -1509,13 +1706,6 @@ dam_desc = "Ť";
 
 	if (take_notes)
 	{
-		s32b len = 10L * TOWN_DAWN;
-		s32b tick = turn % len + len / 4;
-
-		int hour = (24 * tick / len) % 24;
-		int min = (1440 * tick / len) % 60;
-		int prev_min = (1440 * (tick - 10) / len) % 60;
-
 		if (!hour && !min && (min != prev_min))
 			add_note(" ",'D');
 	}
@@ -1523,13 +1713,6 @@ dam_desc = "Ť";
 	/* Nightmare mode activates the TY_CURSE at midnight */
 	if (ironman_nightmare)
 	{
-		s32b len = 10L * TOWN_DAWN;
-		s32b tick = turn % len + len / 4;
-
-		int hour = (24 * tick / len) % 24;
-		int min = (1440 * tick / len) % 60;
-		int prev_min = (1440 * (tick - 10) / len) % 60;
-
 		/* Require exact minute */
 		if (min != prev_min)
 		{
@@ -2279,8 +2462,8 @@ msg_format("ͣв: %d/%d", upkeep_regen, regen_amount);
 			else
 			{
 				if (!disturb_other || (o_ptr->inscription &&
-				    (strchr(quark_str(o_ptr->inscription),'.') ||
-					 strchr(quark_str(o_ptr->inscription),'%'))))
+				    (my_strchr(quark_str(o_ptr->inscription), '.') ||
+					 my_strchr(quark_str(o_ptr->inscription), '%'))))
 				{
 					/* Do nothing */
 					/* msg_print("Teleport aborted.") */ ;
@@ -2508,7 +2691,7 @@ static bool enter_wizard_mode(void)
 
 		/* Mention effects */
 #ifdef JP
-		msg_print("ɥ⡼ɤϥǥХȼ¸ΤΥ⡼ɤǤ ");
+		msg_print("ɥ⡼ɤϥǥХåȼ¸ΤΥ⡼ɤǤ ");
 		msg_print("٥ɥ⡼ɤȥϵϿޤ");
 #else
 		msg_print("Wizard mode is for debugging and experimenting.");
@@ -2567,8 +2750,8 @@ static bool enter_debug_mode(void)
 
 		/* Mention effects */
 #ifdef JP
-		msg_print("ǥХޥɤϥǥХȼ¸ΤΥޥɤǤ ");
-		msg_print("ǥХޥɤȤȥϵϿޤ");
+		msg_print("ǥХåޥɤϥǥХåȼ¸ΤΥޥɤǤ ");
+		msg_print("ǥХåޥɤȤȥϵϿޤ");
 #else
 		msg_print("The debug commands are for debugging and experimenting.");
 		msg_print("The game will not be scored if you use debug commands.");
@@ -2577,7 +2760,7 @@ static bool enter_debug_mode(void)
 
 		/* Verify request */
 #ifdef JP
-		if (!get_check("˥ǥХޥɤȤޤ? "))
+		if (!get_check("˥ǥХåޥɤȤޤ? "))
 #else
 		if (!get_check("Are you sure you want to use debug commands? "))
 #endif
@@ -2591,7 +2774,7 @@ static bool enter_debug_mode(void)
 		if (take_notes)
 		{
 #ifdef JP
-			add_note("ǥХ⡼", 'W');
+			add_note("ǥХå⡼", 'W');
 #else
 			add_note("Debug mode", 'W');
 #endif
@@ -2622,8 +2805,8 @@ static bool enter_borg_mode(void)
 	{
 		/* Mention effects */
 #ifdef JP
-msg_print("ܡޥɤϥǥХȼ¸ΤΥޥɤǤ ");
-msg_print("ܡޥɤȤȥϵϿޤ");
+		msg_print("ܡޥɤϥǥХåȼ¸ΤΥޥɤǤ ");
+		msg_print("ܡޥɤȤȥϵϿޤ");
 #else
 		msg_print("The borg commands are for debugging and experimenting.");
 		msg_print("The game will not be scored if you use borg commands.");
@@ -2633,11 +2816,10 @@ msg_print("ܡޥɤȤȥϵϿޤ");
 
 		/* Verify request */
 #ifdef JP
-if (!get_check("˥ܡޥɤȤޤ? "))
+		if (!get_check("˥ܡޥɤȤޤ? "))
 #else
 		if (!get_check("Are you sure you want to use borg commands? "))
 #endif
-
 		{
 			return (FALSE);
 		}
@@ -2925,21 +3107,21 @@ msg_print("ɥ⡼");
 		/*** Stairs and Doors and Chests and Traps ***/
 
 		/* Enter store */
-		case 253:
+		case SPECIAL_KEY_STORE:
 		{
 			do_cmd_store();
 			break;
 		}
 
 		/* Enter building -KMW- */
-		case 254:
+		case SPECIAL_KEY_BUILDING:
 		{
 			do_cmd_bldg();
 			break;
 		}
 
 		/* Enter quest level -KMW- */
-		case 255:
+		case SPECIAL_KEY_QUEST:
 		{
 			do_cmd_quest();
 			break;
@@ -3009,6 +3191,8 @@ msg_print("ɥ⡼");
 		{
 			if (p_ptr->pclass == CLASS_MINDCRAFTER)
 				do_cmd_mind_browse();
+			else if (p_ptr->pclass == CLASS_ELEMENTALIST)
+				do_cmd_elem_browse();
 			else do_cmd_browse();
 			break;
 		}
@@ -3050,6 +3234,8 @@ msg_print("ɥ⡼");
 				{
 					if (p_ptr->pclass == CLASS_MINDCRAFTER)
 						do_cmd_mindcraft();
+					else if (p_ptr->pclass == CLASS_ELEMENTALIST)
+						do_cmd_element();
 					else
 						do_cmd_cast();
 				}
@@ -3351,7 +3537,7 @@ msg_print("꡼ʤˡۼ");
 		/* XTRA HACK AUTOPICK*/
 		case '$':
 		{
-			do_cmd_pickpref();
+			do_cmd_reload_autopick();
 			break;
 		}
 
@@ -3386,6 +3572,7 @@ msg_print("꡼ʤˡۼ");
 		case '=':
 		{
 			do_cmd_options();
+			(void)combine_and_reorder_home();
 			do_cmd_redraw();
 			break;
 		}
@@ -3462,6 +3649,7 @@ msg_print("꡼ʤˡۼ");
 
 		/* Save and quit */
 		case KTRL('X'):
+		case SPECIAL_KEY_QUIT:
 		{
 			do_cmd_save_and_exit();
 			break;
@@ -3530,6 +3718,59 @@ prt(" '?' ǥإפɽޤ", 0, 0);
 
 
 
+/* Hack -- Pack Overflow */
+static void pack_overflow(void)
+{
+	/* Hack -- Pack Overflow */
+	if (inventory[INVEN_PACK].k_idx)
+	{
+		char o_name[MAX_NLEN];
+		object_type *o_ptr;
+
+		/* Is auto-destroy done? */
+		notice_stuff();
+		if (!inventory[INVEN_PACK].k_idx) return;
+
+		/* Access the slot to be dropped */
+		o_ptr = &inventory[INVEN_PACK];
+
+		/* Disturbing */
+		disturb(0, 0);
+
+		/* Warning */
+#ifdef JP
+		msg_print("å饢ƥबդ줿");
+#else
+		msg_print("Your pack overflows!");
+#endif
+
+		/* Describe */
+		object_desc(o_name, o_ptr, 0);
+
+		/* Message */
+#ifdef JP
+		msg_format("%s(%c)Ȥ", o_name, index_to_label(INVEN_PACK));
+#else
+		msg_format("You drop %s (%c).", o_name, index_to_label(INVEN_PACK));
+#endif
+
+		/* Drop it (carefully) near the player */
+		(void)drop_near(o_ptr, 0, py, px);
+
+		/* Modify, Describe, Optimize */
+		inven_item_increase(INVEN_PACK, -255);
+		inven_item_describe(INVEN_PACK);
+		inven_item_optimize(INVEN_PACK);
+
+		/* Notice stuff */
+		notice_stuff();
+
+		/* Handle stuff */
+		handle_stuff();
+	}
+}
+
+
 /*
  * Process the player
  *
@@ -3635,51 +3876,7 @@ static void process_player(void)
 		if (fresh_before) Term_fresh();
 
 		/* Hack -- Pack Overflow */
-		if (inventory[INVEN_PACK].k_idx)
-		{
-			int item = INVEN_PACK;
-
-			char o_name[MAX_NLEN];
-
-			object_type *o_ptr;
-
-			/* Access the slot to be dropped */
-			o_ptr = &inventory[item];
-
-			/* Disturbing */
-			disturb(0, 0);
-
-			/* Warning */
-#ifdef JP
-			msg_print("å饢ƥबդ줿");
-#else
-			msg_print("Your pack overflows!");
-#endif
-
-			/* Describe */
-			object_desc(o_name, o_ptr, TRUE, 3);
-
-			/* Message */
-#ifdef JP
-			msg_format("%s(%c)Ȥ", o_name, index_to_label(item));
-#else
-			msg_format("You drop %s (%c).", o_name, index_to_label(item));
-#endif
-
-			/* Drop it (carefully) near the player */
-			(void)drop_near(o_ptr, 0, py, px);
-
-			/* Modify, Describe, Optimize */
-			inven_item_increase(item, -255);
-			inven_item_describe(item);
-			inven_item_optimize(item);
-
-			/* Notice stuff */
-			notice_stuff();
-
-			/* Handle stuff */
-			handle_stuff();
-		}
+		pack_overflow();
 
 
 		/* Hack -- cancel "lurking browse mode" */
@@ -3749,14 +3946,20 @@ static void process_player(void)
 			/* Place the cursor on the player */
 			move_cursor_relative(py, px);
 
+			can_save = TRUE;
 			/* Get a command (normal) */
 			request_command(FALSE);
+			can_save = FALSE;
 
 			/* Process the command */
 			process_command();
 		}
 
 
+		/* Hack -- Pack Overflow */
+		pack_overflow();
+
+
 		/*** Clean up ***/
 
 		/* Significant */
@@ -4253,7 +4456,6 @@ static void dungeon(void)
 static void load_all_pref_files(void)
 {
 	char buf[1024];
-	errr err;
 
 	/* Access the "race" pref file */
 	sprintf(buf, "%s.prf", rp_ptr->title);
@@ -4273,29 +4475,8 @@ static void load_all_pref_files(void)
 	/* Process that file */
 	process_pref_file(buf);
 
-	/* Free old entries */
-	init_autopicker();
-
-#ifdef JP
-	sprintf(buf, "picktype-%s.prf", player_base);
-#else
-	sprintf(buf, "pickpref-%s.prf", player_base);
-#endif
-
-	err = process_pickpref_file(buf);
-
-	/* Process 'pick????.prf' if 'pick????-<name>.prf' doesn't exist */
-	if (0 > err)
-	{
-#ifdef JP
-		process_pickpref_file("picktype.prf");
-#else
-		process_pickpref_file("pickpref.prf");
-#endif
-	}
-
 	/* Access the "realm 1" pref file */
-	if (p_ptr->realm1 != REALM_NONE)
+	if ((realm_choices1[p_ptr->pclass]) && (p_ptr->realm1 != REALM_NONE))
 	{
 		sprintf(buf, "%s.prf", realm_names[p_ptr->realm1]);
 
@@ -4311,6 +4492,10 @@ static void load_all_pref_files(void)
 		/* Process that file */
 		process_pref_file(buf);
 	}
+
+
+	/* Load an autopick preference file */
+	autopick_load_pref(FALSE);
 }
 
 
@@ -4481,20 +4666,6 @@ void play_game(bool new_game)
 
 		/* Roll up a new character */
 		player_birth();
-
-		/* Hack -- enter the world */
-		if ((p_ptr->prace == RACE_VAMPIRE) ||
-		    (p_ptr->prace == RACE_SKELETON) ||
-		    (p_ptr->prace == RACE_ZOMBIE) ||
-		    (p_ptr->prace == RACE_SPECTRE))
-		{
-			/* Undead start just after midnight */
-			turn = (30L * TOWN_DAWN) / 4 + 1;
-		}
-		else
-		{
-			turn = 1;
-		}
 	}
 
 	/* Hack - if note file exists, load it */
@@ -4574,6 +4745,9 @@ void play_game(bool new_game)
 	/* Load the "pref" files */
 	load_all_pref_files();
 
+	/* Give startup outfit (after loading pref files) */
+	if (new_game) player_outfit();
+
 	/* React to changes */
 	Term_xtra(TERM_XTRA_REACT, 0);
 
@@ -4594,6 +4768,8 @@ void play_game(bool new_game)
 	/* Hack -- Enforce "delayed death" */
 	if (p_ptr->chp < 0) death = TRUE;
 
+	(void)combine_and_reorder_home();
+
 	/* Process */
 	while (TRUE)
 	{
