@@ -104,8 +104,6 @@
 #include "rooms.h"
 #include "streams.h"
 
-int dun_rooms;
-
 int dun_tun_rnd;
 int dun_tun_chg;
 int dun_tun_con;
@@ -118,6 +116,7 @@ int dun_tun_jct;
  */
 dun_data *dun;
 
+
 /*
  * Places some staircases near walls
  */
@@ -389,97 +388,106 @@ static void try_door(int y, int x)
 }
 
 
-
-/*
- * Generate a new dungeon level
- *
- * Note that "dun_body" adds about 4000 bytes of memory to the stack.
- */
-static bool cave_gen(void)
+/* Place quest monsters */
+void place_quest_monsters(void)
 {
-	int i, j, k, y, x, y1, x1;
+	int i;
 
-	int max_vault_ok = 2;
-
-	int feat1, feat2;
-
-	cave_type *c_ptr;
-
-	bool destroyed = FALSE;
-	bool empty_level = FALSE;
-	bool cavern = FALSE;
-	bool arcade = FALSE;
-	int laketype = 0;
-
-
-	dun_data dun_body;
-
-	/* Prepare allocation table */
-	get_mon_num_prep(get_monster_hook(), NULL);
-
-	/* Global data */
-	dun = &dun_body;
-
-	if (cur_hgt <= SCREEN_HGT / 2 - 2) max_vault_ok--;
-	if (cur_wid <= SCREEN_WID / 2 - 2) max_vault_ok--;
-
-	/* Randomize the dungeon creation values */
-	dun_rooms = rand_range(DUN_ROOMS_MIN, DUN_ROOMS_MAX);
-	dun_tun_rnd = rand_range(DUN_TUN_RND_MIN, DUN_TUN_RND_MAX);
-	dun_tun_chg = rand_range(DUN_TUN_CHG_MIN, DUN_TUN_CHG_MAX);
-	dun_tun_con = rand_range(DUN_TUN_CON_MIN, DUN_TUN_CON_MAX);
-	dun_tun_pen = rand_range(DUN_TUN_PEN_MIN, DUN_TUN_PEN_MAX);
-	dun_tun_jct = rand_range(DUN_TUN_JCT_MIN, DUN_TUN_JCT_MAX);
-
-	/* Empty arena levels */
-	if (ironman_empty_levels || (empty_levels && (randint1(EMPTY_LEVEL) == 1)))
+	/* Handle the quest monster placements */
+	for (i = 0; i < max_quests; i++)
 	{
-		empty_level = TRUE;
+		monster_race *r_ptr;
+		bool group;
+		int j;
 
-		if (cheat_room)
-#ifdef JP
-			msg_print("꡼ʥ٥");
-#else
-			msg_print("Arena level.");
-#endif
-	}
-
-
-	/* Hack -- Start with basic granite */
-	for (y = 0; y < cur_hgt; y++)
-	{
-		for (x = 0; x < cur_wid; x++)
+		if ((quest[i].status != QUEST_STATUS_TAKEN) ||
+		    ((quest[i].type != QUEST_TYPE_KILL_LEVEL) &&
+		     (quest[i].type != QUEST_TYPE_RANDOM)) ||
+		    (quest[i].level != dun_level) ||
+		    (quest[i].flags & QUEST_FLAG_PRESET))
 		{
-			cave_type *c_ptr = &cave[y][x];
+			/* Ignore it */
+			continue;
+		}
 
-			if (empty_level)
-				c_ptr->feat = FEAT_FLOOR;
-			else
-			  /* Create granite wall */
-				c_ptr->feat = FEAT_WALL_EXTRA;
+		r_ptr = &r_info[quest[i].r_idx];
+
+		/* Hack -- "unique" monsters must be "unique" */
+		if ((r_ptr->flags1 & RF1_UNIQUE) &&
+		    (r_ptr->cur_num >= r_ptr->max_num))
+		{
+			/* The unique is already dead */
+			quest[i].status = QUEST_STATUS_FINISHED;
+			continue;
+		}
+
+		group = (r_ptr->flags1 & RF1_FRIENDS) ? FALSE : TRUE;
+
+		for (j = 0; j < (quest[i].max_num - quest[i].cur_num); j++)
+		{
+			int k;
+
+			for (k = 0; k < SAFE_MAX_ATTEMPTS; k++)
+			{
+				int x, y, attempt;
+
+				/* Find an empty grid */
+				for (attempt = SAFE_MAX_ATTEMPTS; attempt; attempt--)
+				{
+					y = randint0(cur_hgt);
+					x = randint0(cur_wid);
+					if (!cave_naked_bold(y, x)) continue;
+					if (distance(y, x, py, px) < 10) continue;
+					else break;
+				}
+
+				/* Failed to place */
+				if (!attempt) break;
+
+				/* Try to place the monster */
+				if (place_monster_aux(y, x, quest[i].r_idx, FALSE, group, FALSE, FALSE))
+				{
+					/* Success */
+					break;
+				}
+				else
+				{
+					/* Failure - Try again */
+					continue;
+				}
+			}
 		}
 	}
+}
 
+
+/*
+ * Generate various caverns and lakes
+ *
+ * There were moved from cave_gen().
+ */
+static void gen_caverns_and_lakes(void)
+{
 #ifdef ALLOW_CAVERNS_AND_LAKES
 	/* Possible "destroyed" level */
-	if ((dun_level > 10) && (randint0(DUN_DEST) == 0) && (small_levels))
+	if ((dun_level > 10) && one_in_(DUN_DEST) && small_levels)
 	{
-		destroyed = TRUE;
+		dun->destroyed = TRUE;
 
 		/* extra rubble around the place looks cool */
-		build_lake(3);
+		build_lake(LAKE_T_CAVE);
 	}
 
 	/* Make a lake some of the time */
-	if ((randint0(LAKE_LEVEL) == 0) && !empty_level && !destroyed && terrain_streams)
+	if (one_in_(LAKE_LEVEL) && !dun->empty_level && !dun->destroyed && terrain_streams)
 	{
 		/* Lake of Water */
-		if (dun_level > 30) laketype = 2;
+		if (dun_level > 30) dun->laketype = LAKE_T_WATER;
 
 		/* Lake of Lava */
-		if (dun_level > 60) laketype = 1;
+		if (dun_level > 60) dun->laketype = LAKE_T_LAVA;
 
-		if (laketype != 0)
+		if (dun->laketype)
 		{
 			if (cheat_room)
 #ifdef JP
@@ -487,14 +495,14 @@ static bool cave_gen(void)
 #else
 				msg_print("Lake on the level.");
 #endif
-			build_lake(laketype);
+			build_lake(dun->laketype);
 		}
 	}
 
-	if ((randint0(DUN_CAV1/(dun_level + DUN_CAV2)) == 0) && !empty_level &&
-	    (laketype == 0) && !destroyed && (dun_level >= MIN_CAVERN))
+	if (one_in_(DUN_CAV1 / (dun_level + DUN_CAV2)) && !dun->empty_level &&
+	    !dun->laketype && !dun->destroyed && (dun_level >= MIN_CAVERN))
 	{
-		cavern = TRUE;
+		dun->cavern = TRUE;
 
 		/* make a large fractal cave in the middle of the dungeon */
 
@@ -509,7 +517,40 @@ static bool cave_gen(void)
 #endif /* ALLOW_CAVERNS_AND_LAKES */
 
 	/* Hack -- No destroyed "quest" levels */
-	if (quest_number(dun_level)) destroyed = FALSE;
+	if (quest_number(dun_level)) dun->destroyed = FALSE;
+}
+
+
+
+/*
+ * Generate a new dungeon level
+ *
+ * Note that "dun_body" adds about 4000 bytes of memory to the stack.
+ */
+static bool cave_gen(void)
+{
+	int i, k, y, x;
+
+	dun_data dun_body;
+
+	/* Global data */
+	dun = &dun_body;
+
+	dun->destroyed = FALSE;
+	dun->empty_level = FALSE;
+	dun->cavern = FALSE;
+	dun->laketype = 0;
+
+
+	/* Prepare allocation table */
+	get_mon_num_prep(get_monster_hook(), NULL);
+
+	/* Randomize the dungeon creation values */
+	dun_tun_rnd = rand_range(DUN_TUN_RND_MIN, DUN_TUN_RND_MAX);
+	dun_tun_chg = rand_range(DUN_TUN_CHG_MIN, DUN_TUN_CHG_MAX);
+	dun_tun_con = rand_range(DUN_TUN_CON_MIN, DUN_TUN_CON_MAX);
+	dun_tun_pen = rand_range(DUN_TUN_PEN_MIN, DUN_TUN_PEN_MAX);
+	dun_tun_jct = rand_range(DUN_TUN_JCT_MIN, DUN_TUN_JCT_MAX);
 
 	/* Actual maximum number of rooms on this level */
 	dun->row_rooms = cur_hgt / BLOCK_HGT;
@@ -524,166 +565,75 @@ static bool cave_gen(void)
 		}
 	}
 
-
-	/* No "crowded" rooms yet */
-	dun->crowded = 0;
-
-
 	/* No rooms yet */
 	dun->cent_n = 0;
 
-	/* Build some rooms */
-	for (i = 0; i < dun_rooms; i++)
+	/* Empty arena levels */
+	if (ironman_empty_levels || (empty_levels && one_in_(EMPTY_LEVEL)))
 	{
-		/* Pick a block for the room */
-		y = randint0(dun->row_rooms);
-		x = randint0(dun->col_rooms);
+		dun->empty_level = TRUE;
 
-		/* Align dungeon rooms */
-		if (dungeon_align)
-		{
-			/* Slide some rooms right */
-			if ((x % 3) == 0) x++;
-
-			/* Slide some rooms left */
-			if ((x % 3) == 2) x--;
-		}
-
-		/* Attempt an "unusual" room */
-		if (ironman_rooms || (randint0(DUN_UNUSUAL) < dun_level))
-		{
-			/* Roll for room type */
-			k = randint0(100);
-
-			/* Attempt a very unusual room */
-			if ((ironman_rooms && (randint0(DUN_UNUSUAL) < dun_level * 2))
-				 || (randint0(DUN_UNUSUAL) < dun_level))
-			{
-#ifdef FORCE_V_IDX
-				if (room_build(y, x, 8)) continue;
-#else
-				/* Type 8 -- Greater vault (10%) */
-				if (k < 10)
-				{
-					if (max_vault_ok > 1)
-					{
-						if (room_build(y, x, 8)) continue;
-					}
-					else
-					{
+		if (cheat_room)
 #ifdef JP
-						if (cheat_room) msg_print("ϲѲޤ");
+			msg_print("꡼ʥ٥");
 #else
-						if (cheat_room) msg_print("Refusing a greater vault.");
+			msg_print("Arena level.");
 #endif
-					}
-				}
-
-				/* Type 7 -- Lesser vault (15%) */
-				if (k < 25)
-				{
-					if (max_vault_ok > 0)
-					{
-						if (room_build(y, x, 7)) continue;
-					}
-					else
-					{
-#ifdef JP
-						if (cheat_room) msg_print("ϲѲޤ");
-#else
-						if (cheat_room) msg_print("Refusing a lesser vault.");
-#endif
-					}
-				}
-
-
-				/* Type 5 -- Monster nest (8%) */
-				if ((k < 33) && room_build(y, x, 5)) continue;
-
-				/* Type 6 -- Monster pit (5%) */
-				if ((k < 38) && room_build(y, x, 6)) continue;
-
-				/* Type 10 -- Random vault (9%) */
-				if (k < 47)
-				{
-					if (max_vault_ok > 0)
-					{
-						if (room_build(y, x, 10)) continue;
-					}
-					else
-					{
-#ifdef JP
-						if (cheat_room) msg_print("ϲѲޤ");
-#else
-						if (cheat_room) msg_print("Refusing a random vault.");
-#endif
-					}
-				}
-
-				/* Type 16 -- Underground Arcade (10%) */
-				if ((k < 57) && !arcade && room_build(y, x, 16))
-				{
-					arcade = TRUE;
-					continue;
-				}
-#endif
-			}
-
-			/* Type 4 -- Large room (15%) */
-			if ((k < 15) && room_build(y, x, 4)) continue;
-
-			/* Type 14 -- Large room (10%) */
-			if ((k < 25) && room_build(y, x, 14)) continue;
-			
-			/* Type 13 -- Large Feature room (5%) */
-			if ((k < 30) && room_build(y, x, 13)) continue;
-			
-			/* Type 3 -- Cross room (20%) */
-			if ((k < 50) && room_build(y, x, 3)) continue;
-
-			/* Type 2 -- Overlapping (25%) */
-			if ((k < 75) && room_build(y, x, 2)) continue;
-			
-			/* Type 15 -- Parallelagram (5%) */
-			if ((k < 80) && room_build(y, x, 15)) continue;
-
-			/* Type 11 -- Circular (5%) */
-			if ((k < 85) && room_build(y, x, 11)) continue;
-
-			/* Type 12 -- Crypt (15%) */
-			if ((k < 100) && room_build(y, x, 12)) continue;
-		}
-
-		/* The deeper you are, the more cavelike the rooms are */
-		k = randint1(100);
-
-		/* No caves when a cavern exists: they look bad */
-		if ((k < dun_level) && (!cavern) && (!empty_level) && (laketype == 0))
-		{
-			/* Type 9 -- Fractal cave */
-			if (room_build(y, x, 9)) continue;
-		}
-		else
-			/* Attempt a "trivial" room */
-		if (room_build(y, x, 1)) continue;
-		continue;
 	}
 
+
+	if (dun->empty_level)
+	{
+		/* Start with floors */
+		for (y = 0; y < cur_hgt; y++)
+		{
+			for (x = 0; x < cur_wid; x++)
+			{
+				cave[y][x].feat = FEAT_FLOOR;
+			}
+		}
+	}
+	else
+	{
+		/* Start with walls */
+		for (y = 0; y < cur_hgt; y++)
+		{
+			for (x = 0; x < cur_wid; x++)
+			{
+				cave[y][x].feat = FEAT_WALL_EXTRA;
+			}
+		}
+	}
+
+
+	/* Generate various caverns and lakes */
+	gen_caverns_and_lakes();
+
+
+	/* Build some rooms */
+
+	/*
+	 * Build each type of room in turn until we cannot build any more.
+	 */
+	generate_rooms();
+
 	/* Make a hole in the dungeon roof sometimes at level 1 */
 	if ((dun_level == 1) && terrain_streams)
 	{
-		while (randint1(DUN_MOS_DEN) == 1)
+		while (one_in_(DUN_MOS_DEN))
 		{
 			place_trees(randint1(cur_wid - 2), randint1(cur_hgt - 2));
 		}
 	}
 
 	/* Destroy the level if necessary */
-	if (destroyed) destroy_level();
+	if (dun->destroyed) destroy_level();
 
 	/* Hack -- Add some rivers */
-	if ((randint1(3) == 1) && (randint1(dun_level) > 5) && terrain_streams)
+	if (one_in_(3) && (randint1(dun_level) > 5) && terrain_streams)
 	{
+		int feat1, feat2;
+
 		/* Choose water or lava */
 		if (randint1(MAX_DEPTH) - 1 > dun_level)
 		{
@@ -698,62 +648,43 @@ static bool cave_gen(void)
 
 
 		/* Only add river if matches lake type or if have no lake at all */
-		if (((laketype == 1) && (feat1 == FEAT_DEEP_LAVA)) ||
-		    ((laketype == 2) && (feat1 == FEAT_DEEP_WATER)) ||
-		     (laketype == 0))
+		if (((dun->laketype == LAKE_T_LAVA) && (feat1 == FEAT_DEEP_LAVA)) ||
+		    ((dun->laketype == LAKE_T_WATER) && (feat1 == FEAT_DEEP_WATER)) ||
+		     !dun->laketype)
 		{
 			add_river(feat1, feat2);
 		}
 	}
 
-	/* Special boundary walls -- Top */
+	/* Special boundary walls -- Top and bottom */
 	for (x = 0; x < cur_wid; x++)
 	{
-		cave_type *c_ptr = &cave[0][x];
-
 		/* Clear previous contents, add "solid" perma-wall */
-		c_ptr->feat = FEAT_PERM_SOLID;
+		cave[0][x].feat = FEAT_PERM_SOLID;
+		cave[cur_hgt - 1][x].feat = FEAT_PERM_SOLID;
 	}
 
-	/* Special boundary walls -- Bottom */
-	for (x = 0; x < cur_wid; x++)
+	/* Special boundary walls -- Left and right */
+	for (y = 1; y < (cur_hgt - 1); y++)
 	{
-		cave_type *c_ptr = &cave[cur_hgt-1][x];
-
 		/* Clear previous contents, add "solid" perma-wall */
-		c_ptr->feat = FEAT_PERM_SOLID;
-	}
-
-	/* Special boundary walls -- Left */
-	for (y = 0; y < cur_hgt; y++)
-	{
-		cave_type *c_ptr = &cave[y][0];
-
-		/* Clear previous contents, add "solid" perma-wall */
-		c_ptr->feat = FEAT_PERM_SOLID;
-	}
-
-	/* Special boundary walls -- Right */
-	for (y = 0; y < cur_hgt; y++)
-	{
-		cave_type *c_ptr = &cave[y][cur_wid-1];
-
-		/* Clear previous contents, add "solid" perma-wall */
-		c_ptr->feat = FEAT_PERM_SOLID;
+		cave[y][0].feat = FEAT_PERM_SOLID;
+		cave[y][cur_wid - 1].feat = FEAT_PERM_SOLID;
 	}
 
 
 	/* Hack -- Scramble the room order */
 	for (i = 0; i < dun->cent_n; i++)
 	{
-		int pick1 = randint0(dun->cent_n);
-		int pick2 = randint0(dun->cent_n);
-		y1 = dun->cent[pick1].y;
-		x1 = dun->cent[pick1].x;
-		dun->cent[pick1].y = dun->cent[pick2].y;
-		dun->cent[pick1].x = dun->cent[pick2].x;
-		dun->cent[pick2].y = y1;
-		dun->cent[pick2].x = x1;
+		int ty, tx;
+		int pick = rand_range(0, i);
+
+		ty = dun->cent[i].y;
+		tx = dun->cent[i].x;
+		dun->cent[i].y = dun->cent[pick].y;
+		dun->cent[i].x = dun->cent[pick].x;
+		dun->cent[pick].y = ty;
+		dun->cent[pick].x = tx;
 	}
 
 	/* Start with no tunnel doors */
@@ -766,18 +697,14 @@ static bool cave_gen(void)
 	/* Connect all the rooms together */
 	for (i = 0; i < dun->cent_n; i++)
 	{
+		int j;
 
 		/* Reset the arrays */
 		dun->tunn_n = 0;
 		dun->wall_n = 0;
 
 		/* Connect the room to the previous room */
-		if (pillar_tunnels && (randint1(20) > dun_level) && (randint1(100) < 25))
-		{
-			/* make catacomb-like tunnel */
-			build_tunnel2(dun->cent[i].x, dun->cent[i].y, x, y, 3, 30);
-		}
-		else if (randint1(dun_level) > 25)
+		if (randint1(dun_level) > 25)
 		{
 			/* make cave-like tunnel */
 			build_tunnel2(dun->cent[i].x, dun->cent[i].y, x, y, 2, 2);
@@ -791,6 +718,8 @@ static bool cave_gen(void)
 		/* Turn the tunnel into corridor */
 		for (j = 0; j < dun->tunn_n; j++)
 		{
+			cave_type *c_ptr;
+
 			/* Access the grid */
 			y = dun->tunn[j].y;
 			x = dun->tunn[j].x;
@@ -809,6 +738,8 @@ static bool cave_gen(void)
 		/* Apply the piercings that we found */
 		for (j = 0; j < dun->wall_n; j++)
 		{
+			cave_type *c_ptr;
+
 			/* Access the grid */
 			y = dun->wall[j].y;
 			x = dun->wall[j].x;
@@ -832,7 +763,7 @@ static bool cave_gen(void)
 		x = dun->cent[i].x;
 	}
 
-	/* Place intersection doors	 */
+	/* Place intersection doors */
 	for (i = 0; i < dun->door_n; i++)
 	{
 		/* Extract junction location */
@@ -865,65 +796,7 @@ static bool cave_gen(void)
 	/* Place 1 or 2 up stairs near some walls */
 	if (!alloc_stairs(FEAT_LESS, rand_range(1, 2), 3)) return FALSE;
 
-
-	/* Handle the quest monster placements */
-	for (i = 0; i < max_quests; i++)
-	{
-		if ((quest[i].status == QUEST_STATUS_TAKEN) &&
-		    ((quest[i].type == QUEST_TYPE_KILL_LEVEL) ||
-		    (quest[i].type == QUEST_TYPE_RANDOM)) &&
-		    (quest[i].level == dun_level) &&
-			!(quest[i].flags & QUEST_FLAG_PRESET))
-		{
-			monster_race *r_ptr = &r_info[quest[i].r_idx];
-
-			/* Hack -- "unique" monsters must be "unique" */
-			if ((r_ptr->flags1 & RF1_UNIQUE) &&
-			    (r_ptr->cur_num >= r_ptr->max_num))
-			{
-				/* The unique is already dead */
-				quest[i].status = QUEST_STATUS_FINISHED;
-			}
-			else
-			{
-				bool group;
-
-				for (j = 0; j < (quest[i].max_num - quest[i].cur_num); j++)
-				{
-					for (k = 0; k < SAFE_MAX_ATTEMPTS; k++)
-					{
-						/* Find an empty grid */
-						while (TRUE)
-						{
-							y = randint0(cur_hgt);
-							x = randint0(cur_wid);
-							if (!cave_naked_bold(y, x)) continue;
-							if (distance(y, x, py, px) < 10) continue;
-							else break;
-						}
-
-						if (r_ptr->flags1 & RF1_FRIENDS)
-							group = FALSE;
-						else
-							group = TRUE;
-
-						/* Try to place the monster */
-						if (place_monster_aux(y, x, quest[i].r_idx, FALSE, group, FALSE, FALSE))
-						{
-							/* Success */
-							break;
-						}
-						else
-						{
-							/* Failure - Try again */
-							continue;
-						}
-					}
-				}
-			}
-		}
-	}
-
+	place_quest_monsters();
 
 	/* Basic "amount" */
 	k = (dun_level / 3);
@@ -980,7 +853,7 @@ static bool cave_gen(void)
 		alloc_object(ALLOC_SET_BOTH, ALLOC_TYP_INVIS, randnor(DUN_AMT_INVIS, 3));
 	}
 
-	if (empty_level && ((randint1(DARK_EMPTY) != 1) || (randint1(100) > dun_level)))
+	if (dun->empty_level && (!one_in_(DARK_EMPTY) || (randint1(100) > dun_level)))
 	{
 		/* Lite the cave */
 		for (y = 0; y < cur_hgt; y++)
@@ -1217,25 +1090,6 @@ static bool level_gen(cptr *why)
 	else return TRUE;
 }
 
-static byte extract_feeling(void)
-{
-	/* Hack -- no feeling in the town */
-	if (!dun_level) return 0;
-
-	/* Hack -- Have a special feeling sometimes */
-	if (good_item_flag && !preserve_mode) return 1;
-
-	if (rating > 100) return 2;
-	if (rating > 80) return 3;
-	if (rating > 60) return 4;
-	if (rating > 40) return 5;
-	if (rating > 30) return 6;
-	if (rating > 20) return 7;
-	if (rating > 10) return 8;
-	if (rating > 0) return 9;
-
-	return 10;
-}
 
 /*
  * Wipe all unnecessary flags after cave generation
@@ -1279,6 +1133,7 @@ void generate_cave(void)
 	for (num = 0; TRUE; num++)
 	{
 		bool okay = TRUE;
+		byte feeling;
 
 		cptr why = NULL;
 
@@ -1333,12 +1188,6 @@ void generate_cave(void)
 		/* Reset the object generation level */
 		object_level = base_level;
 
-		/* Nothing special here yet */
-		good_item_flag = FALSE;
-
-		/* Nothing good here yet */
-		rating = 0;
-
 		/* Build the arena -KMW- */
 		if (p_ptr->inside_arena)
 		{
@@ -1366,7 +1215,7 @@ void generate_cave(void)
 		}
 
 		/* Extract the feeling */
-		feeling = extract_feeling();
+		feeling = get_dungeon_feeling();
 
 		/* Prevent object over-flow */
 		if (o_max >= max_o_idx)
@@ -1452,6 +1301,10 @@ if (why) msg_format("ľ(%s)", why);
 	/* Remember when this level was "created" */
 	old_turn = turn;
 
+	/* No dungeon feeling yet */
+	p_ptr->feeling_turn = old_turn;
+	p_ptr->feeling = 0;
+
 	/* Glow lava in floor */
 	glow_lava_floor();
 }
