@@ -5,20 +5,6 @@
 #include "angband.h"
 
 
-#ifdef JP
-#undef strchr
-static char *_strchr(const char *ptr, char ch)
-{
-	for ( ; *ptr != '\0'; ++ptr)
-	{
-		if (*ptr == ch) return (char *)ptr;
-		if (iskanji(*ptr)) ++ptr;
-	}
-
-	return NULL;
-}
-#define strchr _strchr
-#endif
 /*
  * This file is used to initialize various variables and arrays for the
  * Angband game.  Note the use of "fd_read()" and "fd_write()" to bypass
@@ -613,7 +599,7 @@ static cptr k_info_gen_flags[] =
 	"XTRA_L_RES",
 	"XTRA_D_RES",
 	"XTRA_RES",
-	"XXX",
+	"FIXED_FLAVOR",
 	"XXX",
 	"XXX",
 	"XXX",
@@ -889,7 +875,7 @@ errr parse_v_info(char *buf, header *head)
 	if (buf[0] == 'N')
 	{
 		/* Find the colon before the name */
-		s = strchr(buf+2, ':');
+		s = my_strchr(buf+2, ':');
 
 		/* Verify that colon */
 		if (!s) return (1);
@@ -1003,7 +989,7 @@ errr parse_m_info(char *buf, header *head)
 		int xtra, first, weight;
 
 		/* Find the colon before the name */
-		s = strchr(buf+2, ':');
+		s = my_strchr(buf+2, ':');
 
 		/* Verify that colon */
 		if (!s) return (1);
@@ -1022,7 +1008,7 @@ errr parse_m_info(char *buf, header *head)
 		stat = s;
 
 		/* Find the colon before the name */
-		s = strchr(s, ':');
+		s = my_strchr(s, ':');
 
 		/* Verify that colon */
 		if (!s) return (1);
@@ -1101,7 +1087,7 @@ errr parse_f_info(char *buf, header *head)
 	if (buf[0] == 'N')
 	{
 		/* Find the colon before the name */
-		s = strchr(buf+2, ':');
+		s = my_strchr(buf+2, ':');
 
 			/* Verify that colon */
 		if (!s) return (1);
@@ -1177,23 +1163,87 @@ errr parse_f_info(char *buf, header *head)
 	/* Process 'G' for "Graphics" (one line only) */
 	else if (buf[0] == 'G')
 	{
-		byte tmp;
+		int j;
+		byte s_attr;
+		char char_tmp[F_LIT_MAX];
 
 		/* Paranoia */
-		if (!buf[2]) return (1);
-		if (!buf[3]) return (1);
-		if (!buf[4]) return (1);
+		if (buf[1] != ':') return 1;
+		if (!buf[2]) return 1;
+		if (buf[3] != ':') return 1;
+		if (!buf[4]) return 1;
+
+		/* Extract the char */
+		char_tmp[F_LIT_STANDARD] = buf[2];
 
 		/* Extract the color */
-		tmp = color_char_to_attr(buf[4]);
+		s_attr = color_char_to_attr(buf[4]);
 
 		/* Paranoia */
-		if (tmp > 127) return (1);
+		if (s_attr > 127) return 1;
 
-		/* Save the values */
-		f_ptr->d_attr = tmp;
-		f_ptr->d_char = buf[2];
+		/* Save the standard values */
+		f_ptr->d_attr[F_LIT_STANDARD] = s_attr;
+		f_ptr->d_char[F_LIT_STANDARD] = char_tmp[F_LIT_STANDARD];
 
+		/* Is this feature supports lighting? */
+		if (buf[5] == ':')
+		{
+			/* G:c:a:LIT (default) */
+			apply_default_feat_lighting(f_ptr->d_attr, f_ptr->d_char);
+
+			/* G:c:a:lc:la:dc:da */
+			if (!streq(buf + 6, "LIT"))
+			{
+				char attr_lite_tmp[F_LIT_MAX - F_LIT_NS_BEGIN];
+
+				if ((F_LIT_MAX - F_LIT_NS_BEGIN) * 2 != sscanf(buf + 6, "%c:%c:%c:%c",
+					&char_tmp[F_LIT_LITE], &attr_lite_tmp[F_LIT_LITE - F_LIT_NS_BEGIN],
+					&char_tmp[F_LIT_DARK], &attr_lite_tmp[F_LIT_DARK - F_LIT_NS_BEGIN])) return 1;
+				if (buf[F_LIT_MAX * 4 + 1]) return 1;
+
+				for (j = F_LIT_NS_BEGIN; j < F_LIT_MAX; j++)
+				{
+					switch (attr_lite_tmp[j - F_LIT_NS_BEGIN])
+					{
+					case '*':
+						/* Use default lighting */
+						break;
+					case '-':
+						/* No lighting support */
+						f_ptr->d_attr[j] = f_ptr->d_attr[F_LIT_STANDARD];
+						break;
+					default:
+						/* Extract the color */
+						f_ptr->d_attr[j] = color_char_to_attr(attr_lite_tmp[j - F_LIT_NS_BEGIN]);
+						if (f_ptr->d_attr[j] > 127) return 1;
+						break;
+					}
+					f_ptr->d_char[j] = char_tmp[j];
+				}
+			}
+		}
+		else if (!buf[5])
+		{
+			for (j = F_LIT_NS_BEGIN; j < F_LIT_MAX; j++)
+			{
+				f_ptr->d_attr[j] = s_attr;
+				f_ptr->d_char[j] = char_tmp[F_LIT_STANDARD];
+			}
+		}
+		else return 1;
+	}
+
+	/* Process 'W' for "More Info" (one line only) */
+	else if (buf[0] == 'W')
+	{
+		int priority;
+
+		/* Scan for the value */
+		if (1 != sscanf(buf+2, "%d", &priority)) return PARSE_ERROR_GENERIC;
+
+		/* Save the value */
+		f_ptr->priority = priority;
 	}
 
 	/* Oops */
@@ -1280,19 +1330,19 @@ errr parse_k_info(char *buf, header *head)
 	/* Process 'N' for "New/Number/Name" */
 	if (buf[0] == 'N')
 	{
-		/* Find the colon before the name */
-		s = strchr(buf+2, ':');
+#ifdef JP
+		char *flavor;
+#endif
 
-			/* Verify that colon */
+		/* Find the colon before the name */
+		s = my_strchr(buf+2, ':');
+
+		/* Verify that colon */
 		if (!s) return (1);
 
 		/* Nuke the colon, advance to the name */
 		*s++ = '\0';
 
-#ifdef JP
-		/* Paranoia -- require a name */
-		if (!*s) return (1);
-#endif
 		/* Get the index */
 		i = atoi(buf+2);
 
@@ -1309,6 +1359,22 @@ errr parse_k_info(char *buf, header *head)
 		k_ptr = &k_info[i];
 
 #ifdef JP
+		/* Paranoia -- require a name */
+		if (!*s) return (1);
+
+		/* Find the colon before the flavor */
+		flavor = my_strchr(s, ':');
+
+		/* Verify that colon */
+		if (flavor)
+		{
+			/* Nuke the colon, advance to the flavor */
+			*flavor++ = '\0';
+
+			/* Store the flavor */
+			if (!add_name(&k_ptr->flavor_name, head, flavor)) return (7);
+		}
+
 		/* Store the name */
 		if (!add_name(&k_ptr->name, head, s)) return (7);
 #endif
@@ -1328,9 +1394,24 @@ errr parse_k_info(char *buf, header *head)
 #else
 	else if (buf[0] == 'E')
 	{
-		/* Acquire the Text */
+		char *flavor;
+
+		/* Acquire the name */
 		s = buf+2;
 
+		/* Find the colon before the flavor */
+		flavor = my_strchr(s, ':');
+
+		/* Verify that colon */
+		if (flavor)
+		{
+			/* Nuke the colon, advance to the flavor */
+			*flavor++ = '\0';
+
+			/* Store the flavor */
+			if (!add_name(&k_ptr->flavor_name, head, flavor)) return (7);
+		}
+
 		/* Store the name */
 		if (!add_name(&k_ptr->name, head, s)) return (7);
 	}
@@ -1427,10 +1508,10 @@ errr parse_k_info(char *buf, header *head)
 			k_ptr->locale[i] = atoi(s+1);
 
 				/* Find the slash */
-			t = strchr(s+1, '/');
+			t = my_strchr(s+1, '/');
 
 				/* Find the next colon */
-			s = strchr(s+1, ':');
+			s = my_strchr(s+1, ':');
 
 				/* If the slash is "nearby", use it */
 			if (t && (!s || t < s))
@@ -1604,7 +1685,7 @@ errr parse_a_info(char *buf, header *head)
 	if (buf[0] == 'N')
 	{
 		/* Find the colon before the name */
-		s = strchr(buf+2, ':');
+		s = my_strchr(buf+2, ':');
 
 			/* Verify that colon */
 		if (!s) return (1);
@@ -1859,7 +1940,7 @@ errr parse_e_info(char *buf, header *head)
 	if (buf[0] == 'N')
 	{
 		/* Find the colon before the name */
-		s = strchr(buf+2, ':');
+		s = my_strchr(buf+2, ':');
 
 			/* Verify that colon */
 		if (!s) return (1);
@@ -2161,7 +2242,7 @@ errr parse_r_info(char *buf, header *head)
 	if (buf[0] == 'N')
 	{
 		/* Find the colon before the name */
-		s = strchr(buf+2, ':');
+		s = my_strchr(buf+2, ':');
 
 			/* Verify that colon */
 		if (!s) return (1);
@@ -2616,7 +2697,7 @@ static errr parse_line_building(char *buf)
 
 
 	/* Find the colon after the building number */
-	s = strchr(buf + 2, ':');
+	s = my_strchr(buf + 2, ':');
 
 	/* Verify that colon */
 	if (!s) return (1);
@@ -3255,16 +3336,15 @@ static cptr process_dungeon_file_expr(char **sp, char *fp)
 		/* Function: EQU */
 		else if (streq(t, "EQU"))
 		{
-			v = "1";
+			v = "0";
 			if (*s && (f != b2))
 			{
 				t = process_dungeon_file_expr(&s, &f);
 			}
 			while (*s && (f != b2))
 			{
-				p = t;
-				t = process_dungeon_file_expr(&s, &f);
-				if (*t && !streq(p, t)) v = "0";
+				p = process_dungeon_file_expr(&s, &f);
+				if (streq(t, p)) v = "1";
 			}
 		}
 
@@ -3305,7 +3385,7 @@ static cptr process_dungeon_file_expr(char **sp, char *fp)
 		{
 			while (*s && (f != b2))
 			{
-				t = process_dungeon_file_expr(&s, &f);
+				(void)process_dungeon_file_expr(&s, &f);
 			}
 		}
 
@@ -3320,7 +3400,15 @@ static cptr process_dungeon_file_expr(char **sp, char *fp)
 	else
 	{
 		/* Accept all printables except spaces and brackets */
-		while (isprint(*s) && !strchr(" []", *s)) ++s;
+#ifdef JP
+		while (iskanji(*s) || (isprint(*s) && !my_strchr(" []", *s)))
+		{
+			if (iskanji(*s)) s++;
+			s++;
+		}
+#else
+		while (isprint(*s) && !my_strchr(" []", *s)) ++s;
+#endif
 
 		/* Extract final and Terminate */
 		if ((f = *s) != '\0') *s++ = '\0';
@@ -3373,12 +3461,18 @@ static cptr process_dungeon_file_expr(char **sp, char *fp)
 			/* First realm */
 			else if (streq(b+1, "REALM1"))
 			{
+				if (p_ptr->pclass == CLASS_ELEMENTALIST)
+				{
+					v = element_realm_name();
+				}
+				else
+				{
 #ifdef JP
-				v = E_realm_names[p_ptr->realm1];
+					v = E_realm_names[p_ptr->realm1];
 #else
-				v = realm_names[p_ptr->realm1];
+					v = realm_names[p_ptr->realm1];
 #endif
-
+				}
 			}
 
 			/* Second realm */
@@ -3395,7 +3489,22 @@ static cptr process_dungeon_file_expr(char **sp, char *fp)
 			/* Player name */
 			else if (streq(b+1, "PLAYER"))
 			{
-				v = player_base;
+				static char tmp_player_name[32];
+				char *pn, *tpn;
+				for (pn = player_name, tpn = tmp_player_name; *pn; pn++, tpn++)
+				{
+#ifdef JP
+					if (iskanji(*pn))
+					{
+						*(tpn++) = *(pn++);
+						*tpn = *pn;
+						continue;
+					}
+#endif
+					*tpn = my_strchr(" []", *pn) ? '_' : *pn;
+				}
+				*tpn = '\0';
+				v = tmp_player_name;
 			}
 
 			/* Town */
