@@ -1771,15 +1771,11 @@ struct term_data
 
 	XImage *tiles;
 
-#ifdef USE_TRANSPARENCY
-
 	/* Tempory storage for overlaying tiles. */
 	XImage *TmpImage;
 
 #endif
 
-#endif
-
 };
 
 
@@ -2346,19 +2342,55 @@ static errr Term_xtra_x11(int n, int v)
  */
 static errr Term_curs_x11(int x, int y)
 {
-	/* Draw the cursor */
-	Infoclr_set(xor);
-
-#ifdef JP
-	if (use_bigtile && x + 1 < Term->wid && (Term->old->a[y][x+1] == 255 || (iskanji(Term->old->c[y][x]) && !(Term->old->a[y][x] & 0x80))))
-#else
-	if (use_bigtile && x + 1 < Term->wid && Term->old->a[y][x+1] == 255)
-#endif
-		Infofnt_text_non(x, y, "  ", 2);
+	if (use_graphics)
+	{
+		XDrawRectangle(Metadpy->dpy, Infowin->win, xor->gc,
+			       x * Infofnt->wid + Infowin->ox,
+			       y * Infofnt->hgt + Infowin->oy,
+			       Infofnt->wid - 1, Infofnt->hgt - 1);
+		XDrawRectangle(Metadpy->dpy, Infowin->win, xor->gc,
+			       x * Infofnt->wid + Infowin->ox + 1,
+			       y * Infofnt->hgt + Infowin->oy + 1,
+			       Infofnt->wid - 3, Infofnt->hgt - 3);
+	}
 	else
-	/* Hilite the cursor character */
-	Infofnt_text_non(x, y, " ", 1);
+	{
+		/* Draw the cursor */
+		Infoclr_set(xor);
 
+		/* Hilite the cursor character */
+		Infofnt_text_non(x, y, " ", 1);
+	}
+
+	/* Success */
+	return (0);
+}
+
+
+/*
+ * Draw the double width cursor
+ */
+static errr Term_bigcurs_x11(int x, int y)
+{
+	if (use_graphics)
+	{
+		XDrawRectangle(Metadpy->dpy, Infowin->win, xor->gc,
+			       x * Infofnt->wid + Infowin->ox,
+			       y * Infofnt->hgt + Infowin->oy,
+			       Infofnt->twid - 1, Infofnt->hgt - 1);
+		XDrawRectangle(Metadpy->dpy, Infowin->win, xor->gc,
+			       x * Infofnt->wid + Infowin->ox + 1,
+			       y * Infofnt->hgt + Infowin->oy + 1,
+			       Infofnt->twid - 3, Infofnt->hgt - 3);
+	}
+	else
+	{
+		/* Draw the cursor */
+		Infoclr_set(xor);
+
+		/* Hilite the cursor character */
+		Infofnt_text_non(x, y, "  ", 2);
+	}
 	/* Success */
 	return (0);
 }
@@ -2401,18 +2433,13 @@ static errr Term_text_x11(int x, int y, int n, byte a, cptr s)
 /*
  * Draw some graphical characters.
  */
-# ifdef USE_TRANSPARENCY
 static errr Term_pict_x11(int x, int y, int n, const byte *ap, const char *cp, const byte *tap, const char *tcp)
-# else /* USE_TRANSPARENCY */
-static errr Term_pict_x11(int x, int y, int n, const byte *ap, const char *cp)
-# endif /* USE_TRANSPARENCY */
 {
 	int i, x1, y1;
 
 	byte a;
 	char c;
 
-#ifdef USE_TRANSPARENCY
 	byte ta;
 	char tc;
 
@@ -2420,7 +2447,6 @@ static errr Term_pict_x11(int x, int y, int n, const byte *ap, const char *cp)
 	int k,l;
 
 	unsigned long pixel, blank;
-#endif /* USE_TRANSPARENCY */
 
 	term_data *td = (term_data*)(Term->data);
 
@@ -2440,15 +2466,13 @@ static errr Term_pict_x11(int x, int y, int n, const byte *ap, const char *cp)
 		x1 = (c&0x7F) * td->fnt->twid;
 		y1 = (a&0x7F) * td->fnt->hgt;
 
-#ifdef USE_TRANSPARENCY
-
 		ta = *tap++;
 		tc = *tcp++;
 
 		/* For extra speed - cache these values */
 		x2 = (tc&0x7F) * td->fnt->twid;
 		y2 = (ta&0x7F) * td->fnt->hgt;
-		
+
 		/* Optimise the common case */
 		if ((x1 == x2) && (y1 == y2))
 		{
@@ -2458,7 +2482,7 @@ static errr Term_pict_x11(int x, int y, int n, const byte *ap, const char *cp)
 				td->tiles,
 				x1, y1,
 				x, y,
-				td->fnt->twid, td->fnt->hgt);	
+				td->fnt->twid, td->fnt->hgt);
 		}
 		else
 		{
@@ -2491,18 +2515,6 @@ static errr Term_pict_x11(int x, int y, int n, const byte *ap, const char *cp)
 			     0, 0, x, y,
 			     td->fnt->twid, td->fnt->hgt);
 		}
-
-#else /* USE_TRANSPARENCY */
-
-		/* Draw object / terrain */
-		XPutImage(Metadpy->dpy, td->win->win,
-			  clr[0]->gc,
-			  td->tiles,
-			  x1, y1,
-			  x, y,
-			  td->fnt->twid, td->fnt->hgt);
-
-#endif /* USE_TRANSPARENCY */
 	}
 
 	/* Success */
@@ -2922,6 +2934,7 @@ static errr term_data_init(term_data *td, int i)
 	/* Hooks */
 	t->xtra_hook = Term_xtra_x11;
 	t->curs_hook = Term_curs_x11;
+	t->bigcurs_hook = Term_bigcurs_x11;
 	t->wipe_hook = Term_wipe_x11;
 	t->text_hook = Term_text_x11;
 
@@ -2955,10 +2968,7 @@ errr init_x11(int argc, char *argv[])
 	int pict_wid = 0;
 	int pict_hgt = 0;
 
-#ifdef USE_TRANSPARENCY
-
 	char *TmpData;
-#endif /* USE_TRANSPARENCY */
 
 #endif /* USE_GRAPHICS */
 
@@ -3162,7 +3172,6 @@ errr init_x11(int argc, char *argv[])
 				    td->fnt->twid, td->fnt->hgt);
 		}
 
-#ifdef USE_TRANSPARENCY
 		/* Initialize the transparency masks */
 		for (i = 0; i < num_term; i++)
 		{
@@ -3187,8 +3196,6 @@ errr init_x11(int argc, char *argv[])
 				td->fnt->twid, td->fnt->hgt, 8, 0);
 
 		}
-#endif /* USE_TRANSPARENCY */
-
 
 		/* Free tiles_raw? XXX XXX */
 	}
