@@ -912,7 +912,7 @@ static bool find_hiding(int m_idx, int *yp, int *xp)
 	int gy = 0, gx = 0, gdis = 999;
 
 	sint *y_offsets, *x_offsets;
-	
+
 	cave_type *c_ptr;
 
 	/* Start with adjacent locations, spread further */
@@ -929,17 +929,17 @@ static bool find_hiding(int m_idx, int *yp, int *xp)
 		{
 			y = fy + dy;
 			x = fx + dx;
-			
+
 			/* Skip illegal locations */
 			if (!in_bounds(y, x)) continue;
 
 			c_ptr = &cave[y][x];
 
 			/* Skip occupied locations */
-			if (!cave_empty_bold(y,x)) continue;
+			if (!cave_empty_grid(c_ptr)) continue;
 
 			/* Check for hidden, available grid */
-			if (!player_has_los_bold(y,x) && clean_shot(fy, fx, y, x, FALSE))
+			if (!player_has_los_grid(c_ptr) && clean_shot(fy, fx, y, x, FALSE))
 			{
 				/* Calculate distance from player */
 				dis = distance(y, x, py, px);
@@ -1322,7 +1322,7 @@ static bool monst_attack_monst(int m_idx, int t_idx)
 	bool            blinked = FALSE, touched = FALSE;
 	bool			explode = FALSE;
 	bool			fear = FALSE;
-	bool			heal_effect = FALSE;
+	bool			heal_effect;
 	byte            y_saver = t_ptr->fy;
 	byte            x_saver = t_ptr->fx;
 
@@ -1358,9 +1358,6 @@ static bool monst_attack_monst(int m_idx, int t_idx)
 	/* Get the "died from" information (i.e. "a kobold") */
 	monster_desc(ddesc, m_ptr, 0x88);
 
-	/* Assume no blink */
-	blinked = FALSE;
-
 	if (!see_either && known)
 	{
 		mon_fight = TRUE;
@@ -1371,7 +1368,7 @@ static bool monst_attack_monst(int m_idx, int t_idx)
 	{
 		bool obvious = FALSE;
 
-		int power = 0;
+		int power;
 		int damage = 0;
 
 		cptr act = NULL;
@@ -2233,20 +2230,17 @@ static void process_monster(int m_idx)
 				/* Notice the "waking up" */
 				if (m_ptr->ml)
 				{
-					if (visible)
-					{
-						char m_name[80];
+					char m_name[80];
 
-						/* Acquire the monster name */
-						monster_desc(m_name, m_ptr, 0);
+					/* Acquire the monster name */
+					monster_desc(m_name, m_ptr, 0);
 
-						/* Dump a message */
+					/* Dump a message */
 #ifdef JP
-						msg_format("%^sܤФޤ", m_name);
+					msg_format("%^sܤФޤ", m_name);
 #else
-						msg_format("%^s wakes up.", m_name);
+					msg_format("%^s wakes up.", m_name);
 #endif
-					}
 
 					/* Redraw the health bar */
 					if (p_ptr->health_who == m_idx)
@@ -2356,23 +2350,27 @@ static void process_monster(int m_idx)
 		/* Reduce by one, note if expires */
 		m_ptr->invulner--;
 
-		if (!(m_ptr->invulner) && visible)
+		if (!m_ptr->invulner)
 		{
-			char m_name[80];
+			if (ironman_hengband) m_ptr->energy_need += ENERGY_NEED();
 
-			/* Acquire the monster name */
-			monster_desc(m_name, m_ptr, 0);
+			if (visible)
+			{
+				char m_name[80];
 
-			/* Dump a message */
+				/* Acquire the monster name */
+				monster_desc(m_name, m_ptr, 0);
+
+				/* Dump a message */
 #ifdef JP
-			msg_format("%^sϤ⤦̵ŨǤʤ", m_name);
+				msg_format("%^sϤ⤦̵ŨǤʤ", m_name);
 #else
-			msg_format("%^s is no longer invulnerable.", m_name);
+				msg_format("%^s is no longer invulnerable.", m_name);
 #endif
 
-			/* Update health bar as needed */
-			if (ironman_hengband) m_ptr->energy_need += ENERGY_NEED();
-			if (p_ptr->health_who == m_idx) p_ptr->redraw |= (PR_HEALTH);
+				/* Update health bar as needed */
+				if (p_ptr->health_who == m_idx) p_ptr->redraw |= (PR_HEALTH);
+			}
 		}
 	}
 
@@ -3117,7 +3115,9 @@ static void process_monster(int m_idx)
 
 				/* Wake up the moved monster */
 				y_ptr->csleep = 0;
-				if (r_info[y_ptr->r_idx].flags7 & (RF7_HAS_LITE_1 | RF7_HAS_LITE_2)) p_ptr->update |= (PU_MON_LITE);
+
+				if (r_info[y_ptr->r_idx].flags7 & (RF7_HAS_LITE_1 | RF7_SELF_LITE_1 | RF7_HAS_LITE_2 | RF7_SELF_LITE_2))
+					p_ptr->update |= (PU_MON_LITE);
 			}
 
 			/* Hack -- Update the new location */
@@ -3181,7 +3181,7 @@ static void process_monster(int m_idx)
 					object_flags(o_ptr, &f1, &f2, &f3);
 
 					/* Acquire the object name */
-					object_desc(o_name, o_ptr, TRUE, 3);
+					object_desc(o_name, o_ptr, 0);
 
 					/* Acquire the monster name */
 					monster_desc(m_name, m_ptr, 0x04);
@@ -3242,7 +3242,7 @@ static void process_monster(int m_idx)
 						excise_object_idx(this_o_idx);
 
 						/* Forget mark */
-						o_ptr->marked = FALSE;
+						o_ptr->marked &= OM_TOUCHED;
 
 						/* Forget location */
 						o_ptr->iy = o_ptr->ix = 0;
