@@ -123,6 +123,9 @@ bool teleport_away(int m_idx, int dis)
 	/* Redraw the new grid */
 	lite_spot(ny, nx);
 
+	if (r_info[m_ptr->r_idx].flags7 & (RF7_HAS_LITE_1 | RF7_SELF_LITE_1 | RF7_HAS_LITE_2 | RF7_SELF_LITE_2))
+		p_ptr->update |= (PU_MON_LITE);
+
 	return (TRUE);
 }
 
@@ -231,7 +234,8 @@ void teleport_to_player(int m_idx, int power)
 	/* Redraw the new grid */
 	lite_spot(ny, nx);
 
-	p_ptr->update |= (PU_MON_LITE);
+	if (r_info[m_ptr->r_idx].flags7 & (RF7_HAS_LITE_1 | RF7_SELF_LITE_1 | RF7_HAS_LITE_2 | RF7_SELF_LITE_2))
+		p_ptr->update |= (PU_MON_LITE);
 }
 
 
@@ -253,7 +257,7 @@ void teleport_player(int dis)
 	int d, i, min, ox, oy;
 	int tries = 0;
 
-	int xx = -1, yy = -1;
+	int xx = -1, yy;
 
 	/* Initialize */
 	int y = py;
@@ -652,6 +656,8 @@ bool apply_disenchant(int mode)
 	object_type     *o_ptr;
 	char            o_name[MAX_NLEN];
 
+	/* Unused */
+	(void)mode;
 
 	/* Pick a random slot */
 	switch (randint1(8))
@@ -682,7 +688,7 @@ bool apply_disenchant(int mode)
 
 
 	/* Describe the object */
-	object_desc(o_name, o_ptr, FALSE, 0);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 
 	/* Artifacts have 71% chance to resist */
@@ -911,7 +917,7 @@ void brand_weapon(int brand_type)
 
 		/* Let's get the name before it is changed... */
 		char o_name[MAX_NLEN];
-		object_desc(o_name, o_ptr, FALSE, 0);
+		object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 		switch (brand_type)
 		{
@@ -1079,7 +1085,6 @@ take_hit(100 + randint1(150), "Ūʵ̵");
 void fetch(int dir, int wgt, bool require_los)
 {
 	int             ty, tx, i;
-	bool            flag;
 	cave_type       *c_ptr;
 	object_type     *o_ptr;
 	char            o_name[MAX_NLEN];
@@ -1156,7 +1161,6 @@ msg_print("Ϥʤλ볦äƤޤ");
 		/* Use a direction */
 		ty = py; /* Where to drop the item */
 		tx = px;
-		flag = FALSE;
 
 		do
 		{
@@ -1191,7 +1195,7 @@ msg_print("ΥƥϽŲ᤮ޤ");
 	o_ptr->iy = (byte)py;
 	o_ptr->ix = (byte)px;
 
-	object_desc(o_name, o_ptr, TRUE, 0);
+	object_desc(o_name, o_ptr, OD_NAME_ONLY);
 #ifdef JP
 msg_format("%^sʤ­Ǥ", o_name);
 #else
@@ -1298,6 +1302,9 @@ void identify_pack(void)
 
 		/* Identify it */
 		identify_item(o_ptr);
+
+		/* Auto-inscription */
+		autopick_alter_item(i, FALSE);
 	}
 }
 
@@ -1459,7 +1466,7 @@ s = "Ѥʪޤ";
 	/* Describe the object */
 	old_number = o_ptr->number;
 	o_ptr->number = amt;
-	object_desc(o_name, o_ptr, TRUE, 3);
+	object_desc(o_name, o_ptr, 0);
 	o_ptr->number = old_number;
 
 	/* Verify unless quantity given */
@@ -1875,7 +1882,7 @@ s = "Ǥ륢ƥबʤ";
 
 
 	/* Description */
-	object_desc(o_name, o_ptr, FALSE, 0);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 	/* Describe */
 #ifdef JP
@@ -1953,7 +1960,7 @@ s = "忩ɻߤǤ륢ƥबʤ";
 
 
 	/* Description */
-	object_desc(o_name, o_ptr, FALSE, 0);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 	/* Describe */
 #ifdef JP
@@ -2012,7 +2019,7 @@ s = "Ǥ륢ƥबʤ";
 
 
 	/* Description */
-	object_desc(o_name, o_ptr, FALSE, 0);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 	/* Describe */
 #ifdef JP
@@ -2108,103 +2115,6 @@ msg_print("˼Ԥ");
 }
 
 
-/*
- * Apply good luck to an object
- */
-static void good_luck(object_type *o_ptr)
-{
-	/* Objects become better sometimes */
-	if (!randint0(13))
-	{
-		int number = o_ptr->number;
-
-		bool great = ego_item_p(o_ptr);
-
-		/* Prepare it */
-		object_prep(o_ptr, o_ptr->k_idx);
-
-		/* Restore the number */
-		o_ptr->number = number;
-
-		/* Apply good magic (allow artifacts, good, great if an ego-item, no curse) */
-		apply_magic(o_ptr, dun_level, TRUE, TRUE, great, FALSE);
-	}
-
-	/* Objects duplicate sometimes */
-	if (!randint0(777) && (o_ptr->number < 99))
-	{
-		o_ptr->number++;
-	}
-}
-
-
-/*
- * Apply bad luck to an object
- */
-static void bad_luck(object_type *o_ptr)
-{
-	bool is_art = artifact_p(o_ptr) || o_ptr->art_name;
-
-	/* Objects become worse sometimes */
-	if (!randint0(13))
-	{
-		int number = o_ptr->number;
-
-		bool great = ego_item_p(o_ptr);
-
-		/* Non-artifacts get rerolled */
-		if (!is_art)
-		{
-			o_ptr->ident |= IDENT_CURSED;
-
-			/* Prepare it */
-			object_prep(o_ptr, o_ptr->k_idx);
-
-			/* Restore the number */
-			o_ptr->number = number;
-
-			/* Apply bad magic (disallow artifacts, good, great if an ego-item, cursed) */
-			apply_magic(o_ptr, dun_level, FALSE, TRUE, great, TRUE);
-		}
-
-		/* Now curse it */
-		o_ptr->ident |= IDENT_CURSED;
-	}
-
-	/* Objects are blasted sometimes */
-	if (!randint0(666) && (!is_art || !randint0(3)))
-	{
-		/* Blast it */
-		o_ptr->name1 = 0;
-		o_ptr->name2 = EGO_BLASTED;
-		if (o_ptr->to_a) o_ptr->to_a = 0 - randint1(5) - randint1(5);
-		if (o_ptr->to_h) o_ptr->to_h = 0 - randint1(5) - randint1(5);
-		if (o_ptr->to_d) o_ptr->to_d = 0 - randint1(5) - randint1(5);
-		o_ptr->ac = 0;
-		o_ptr->dd = 1;
-		o_ptr->ds = 1;
-		o_ptr->art_flags1 = 0;
-		o_ptr->art_flags2 = 0;
-		o_ptr->art_flags3 = 0;
-
-		/* Curse it */
-		o_ptr->ident |= (IDENT_CURSED);
-
-		/* Break it */
-		o_ptr->ident |= (IDENT_BROKEN);
-
-		/* Recalculate bonuses */
-		p_ptr->update |= (PU_BONUS);
-
-		/* Recalculate mana */
-		p_ptr->update |= (PU_MANA);
-
-		/* Window stuff */
-		p_ptr->window |= (PW_INVEN | PW_EQUIP | PW_PLAYER);
-	}
-}
-
-
 /*
  * Identify an object
  */
@@ -2220,6 +2130,9 @@ bool identify_item(object_type *o_ptr)
 	object_aware(o_ptr);
 	object_known(o_ptr);
 
+	/* Player touches it */
+	o_ptr->marked |= OM_TOUCHED;
+
 	/* Recalculate bonuses */
 	p_ptr->update |= (PU_BONUS);
 
@@ -2233,7 +2146,7 @@ bool identify_item(object_type *o_ptr)
 	 * If the item was an artifact, and if the
 	 * auto-note is selected, write a message (if not written before).
 	 */
-	object_desc(o_name, o_ptr, TRUE, 0);
+	object_desc(o_name, o_ptr, OD_NAME_ONLY);
 	
 	if (take_notes && record_artifact)
 	{
@@ -2264,48 +2177,64 @@ static bool item_tester_hook_identify(object_type *o_ptr)
  * This routine does *not* automatically combine objects.
  * Returns TRUE if something was identified, else FALSE.
  */
-bool ident_spell(bool wait_optimize)
+bool ident_spell(void)
 {
 	int             item;
 	object_type     *o_ptr;
 	char            o_name[MAX_NLEN];
 	cptr            q, s;
 	bool old_known;
-	int idx;
-	
+
 	item_tester_hook = item_tester_hook_identify;
-	if (!can_get_item()) item_tester_hook = NULL;
-	
+
+	/* Get an item */
+	if (can_get_item())
+	{
+#ifdef JP
+		q = "ɤΥƥꤷޤ? ";
+#else
+		q = "Identify which item? ";
+#endif
+	}
+	else
+	{
+		item_tester_hook = NULL;
+
+#ifdef JP
+		q = "٤ƴѤߤǤ ";
+#else
+		q = "All items are identified. ";
+#endif
+	}
+
 	/* Get an item */
 #ifdef JP
-	q = "ɤΥƥꤷޤ? ";
-	s = "Ǥ륢ƥबʤ";
+	s = "ꤹ٤ƥबʤ";
 #else
-	q = "Identify which item? ";
 	s = "You have nothing to identify.";
 #endif
-	
+
 	if (!get_item(&item, q, s, (USE_EQUIP | USE_INVEN | USE_FLOOR))) return (FALSE);
-	
+
 	/* Get the item (in the pack) */
 	if (item >= 0)
 	{
 		o_ptr = &inventory[item];
 	}
-	
+
 	/* Get the item (on the floor) */
 	else
 	{
 		o_ptr = &o_list[0 - item];
 	}
-	
-	
+
+
 	/* Identify it */
 	old_known = identify_item(o_ptr);
-	
+
 	/* Description */
-	object_desc(o_name, o_ptr, TRUE, 3);
-	
+	object_desc(o_name, o_ptr, 0);
+
 	/* Describe */
 	if (item >= INVEN_WIELD)
 	{
@@ -2336,10 +2265,7 @@ bool ident_spell(bool wait_optimize)
 	}
 
 	/* Auto-inscription/destroy */
-	idx = is_autopick(o_ptr);
-	auto_inscribe_item(item, idx);
-	if (destroy_identify && !old_known)
-		auto_destroy_item(item, idx);
+	autopick_alter_item(item, (bool)(destroy_identify && !old_known));
 
 	/* Something happened */
 	return (TRUE);
@@ -2470,25 +2396,40 @@ static bool item_tester_hook_identify_fully(object_type *o_ptr)
  * Fully "identify" an object in the inventory  -BEN-
  * This routine returns TRUE if an item was identified.
  */
-bool identify_fully(bool wait_optimize)
+bool identify_fully(void)
 {
 	int             item;
 	object_type     *o_ptr;
 	char            o_name[MAX_NLEN];
 	cptr            q, s;
 	bool old_known;
-	int idx;
 
 	item_tester_hook = item_tester_hook_identify_fully;
-	if (!can_get_item()) item_tester_hook = NULL;
+
+	if (can_get_item())
+	{
+#ifdef JP
+		q = "ɤΥƥ**ޤ? ";
+#else
+		q = "*Identify* which item? ";
+#endif
+	}
+	else
+	{
+		item_tester_hook = NULL;
+
+#ifdef JP
+		q = "٤**ѤߤǤ ";
+#else
+		q = "All items are *identified*. ";
+#endif
+	}
 
 	/* Get an item */
 #ifdef JP
-	q = "ɤΥƥꤷޤ? ";
-	s = "Ǥ륢ƥबʤ";
+	s = "**٤ƥबʤ";
 #else
-	q = "Identify which item? ";
-	s = "You have nothing to identify.";
+	s = "You have nothing to *identify*.";
 #endif
 
 	if (!get_item(&item, q, s, (USE_EQUIP | USE_INVEN | USE_FLOOR))) return (FALSE);
@@ -2515,7 +2456,7 @@ bool identify_fully(bool wait_optimize)
 	handle_stuff();
 
 	/* Description */
-	object_desc(o_name, o_ptr, TRUE, 3);
+	object_desc(o_name, o_ptr, 0);
 
 	/* Describe */
 	if (item >= INVEN_WIELD)
@@ -2550,10 +2491,7 @@ bool identify_fully(bool wait_optimize)
 	(void)identify_fully_aux(o_ptr, TRUE);
 
 	/* Auto-inscription/destroy */
-	idx = is_autopick(o_ptr);
-	auto_inscribe_item(item, idx);
-	if (destroy_identify && !old_known)
-		auto_destroy_item(item, idx);
+	autopick_alter_item(item, (bool)(destroy_identify && !old_known));
 
 	/* Success */
 	return (TRUE);
@@ -2740,7 +2678,7 @@ s = "ϤŶ٤ƥबʤ";
 		/* Artifacts are never destroyed. */
 		if (artifact_p(o_ptr))
 		{
-			object_desc(o_name, o_ptr, TRUE, 0);
+			object_desc(o_name, o_ptr, OD_NAME_ONLY);
 #ifdef JP
 msg_format("Ϥή%sϴϤ򼺤ä", o_name);
 #else
@@ -2759,7 +2697,7 @@ msg_format("Ϥή%sϴϤ򼺤ä", o_name);
 		else
 		{
 			/* Get the object description */
-			object_desc(o_name, o_ptr, FALSE, 0);
+			object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 			/*** Determine Seriousness of Failure ***/
 
@@ -2965,7 +2903,7 @@ s = "ʡǤ郎ޤ";
 
 
 	/* Description */
-	object_desc(o_name, o_ptr, FALSE, 0);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 	/* Extract the flags */
 	object_flags(o_ptr, &f1, &f2, &f3);
@@ -3258,6 +3196,66 @@ bool potion_smash_effect(int who, int y, int x, int k_idx)
 }
 
 
+s16b get_spell_chance(int fail, int min_lev, int mana_cost)
+{
+	int chance, minfail;
+	bool dc = (p_ptr->pclass == CLASS_MINDCRAFTER) ? FALSE : p_ptr->dec_mana;
+
+	/* Get the failure rate */
+	chance = fail;
+
+	/* Reduce failure rate by "effective" level adjustment */
+	chance -= 3 * (p_ptr->lev - min_lev);
+
+	/* Reduce failure rate by INT/WIS adjustment */
+	chance -= 3 * (adj_mag_stat[p_ptr->stat_ind[mp_ptr->spell_stat]] - 1);
+
+	/* Not enough mana to cast */
+	if (mana_cost > p_ptr->csp)
+	{
+		chance += 5 * (mana_cost - p_ptr->csp);
+	}
+
+	/* Reduce failure rate by dec_mana */
+	if (dc) chance -= 2;
+
+	/* Extract the minimum failure rate */
+	minfail = adj_mag_fail[p_ptr->stat_ind[mp_ptr->spell_stat]];
+
+	/*
+	 * Non mage/priest characters never get too good
+	 * (added high mage, mindcrafter)
+	 */
+	if ((p_ptr->pclass != CLASS_PRIEST) &&
+	    (p_ptr->pclass != CLASS_MAGE) &&
+	    (p_ptr->pclass != CLASS_MINDCRAFTER) &&
+	    (p_ptr->pclass != CLASS_HIGH_MAGE) &&
+	    (p_ptr->pclass != CLASS_ELEMENTALIST))
+	{
+		if (minfail < 5) minfail = 5;
+	}
+
+	/* Hack -- Priest prayer penalty for "edged" weapons  -DGK */
+	if ((p_ptr->pclass == CLASS_PRIEST) && p_ptr->icky_wield) chance += 25;
+
+	/* Minimum failure rate */
+	if (chance < minfail) chance = minfail;
+
+	/* Stunning makes spells harder */
+	if (p_ptr->stun > 50) chance += 25;
+	else if (p_ptr->stun) chance += 15;
+
+	/* Always a 5 percent chance of working */
+	if (chance > 95) chance = 95;
+
+	if (dc) chance--;
+
+	chance = MAX(chance, 0);
+
+	return (chance);
+}
+
+
 /*
  * Hack -- Display all known spells in a window
  *
@@ -3289,7 +3287,6 @@ void display_spell_list(void)
 		int             i;
 		int             y = 1;
 		int             x = 1;
-		int             minfail;
 		int             plev = p_ptr->lev;
 		int             chance;
 		mindcraft_power spell;
@@ -3299,51 +3296,21 @@ void display_spell_list(void)
 		/* Display a list of spells */
 		prt("", y, x);
 #ifdef JP
-put_str("̾", y, x + 5);
-put_str("Lv   MP Ψ ", y, x + 35);
+		put_str("̾", y, x + 5);
+		put_str("Lv   MP Ψ ", y, x + 35);
 #else
 		put_str("Name", y, x + 5);
 		put_str("Lv Mana Fail Info", y, x + 35);
 #endif
 
-
 		/* Dump the spells */
 		for (i = 0; i < MAX_MINDCRAFT_POWERS; i++)
 		{
-			byte a = TERM_WHITE;
-
 			/* Access the available spell */
 			spell = mindcraft_powers[i];
 			if (spell.min_lev > plev) break;
 
-			/* Get the failure rate */
-			chance = spell.fail;
-
-			/* Reduce failure rate by "effective" level adjustment */
-			chance -= 3 * (p_ptr->lev - spell.min_lev);
-
-			/* Reduce failure rate by INT/WIS adjustment */
-			chance -= 3 * (adj_mag_stat[p_ptr->stat_ind[mp_ptr->spell_stat]] - 1);
-
-			/* Not enough mana to cast */
-			if (spell.mana_cost > p_ptr->csp)
-			{
-				chance += 5 * (spell.mana_cost - p_ptr->csp);
-				a = TERM_ORANGE;
-			}
-
-			/* Extract the minimum failure rate */
-			minfail = adj_mag_fail[p_ptr->stat_ind[mp_ptr->spell_stat]];
-
-			/* Minimum failure rate */
-			if (chance < minfail) chance = minfail;
-
-			/* Stunning makes spells harder */
-			if (p_ptr->stun > 50) chance += 25;
-			else if (p_ptr->stun) chance += 15;
-
-			/* Always a 5 percent chance of working */
-			if (chance > 95) chance = 95;
+			chance = get_spell_chance(spell.fail, spell.min_lev, spell.mana_cost);
 
 			/* Get info */
 			mindcraft_info(comment, i);
@@ -3353,11 +3320,18 @@ put_str("Lv   MP Ψ ", y, x + 35);
 			    I2A(i), spell.name,
 			    spell.min_lev, spell.mana_cost, chance, comment);
 
-			Term_putstr(x, y + i + 1, -1, a, psi_desc);
+			Term_putstr(x, y + i + 1, -1, TERM_WHITE, psi_desc);
 		}
 		return;
 	}
 
+
+	if (p_ptr->pclass == CLASS_ELEMENTALIST)
+	{
+		display_element_list();
+		return;
+	}
+
 	/* Normal spellcaster with books */
 
 	/* Scan books */
@@ -3443,13 +3417,12 @@ strcpy(name, "(Ƚǽ)");
 }
 
 
-
 /*
  * Returns spell chance of failure for spell -RAK-
  */
 s16b spell_chance(int spell, int realm)
 {
-	int             chance, minfail;
+	int             chance;
 	magic_type      *s_ptr;
 	byte            use_mana;
 
@@ -3461,54 +3434,7 @@ s16b spell_chance(int spell, int realm)
 	s_ptr = &mp_ptr->info[realm][spell];
 	use_mana = get_modified_smana(s_ptr);
 
-	/* Extract the base spell failure rate */
-	chance = s_ptr->sfail;
-
-	/* Reduce failure rate by "effective" level adjustment */
-	chance -= 3 * (p_ptr->lev - s_ptr->slevel);
-
-	/* Reduce failure rate by INT/WIS adjustment */
-	chance -= 3 * (adj_mag_stat[p_ptr->stat_ind[mp_ptr->spell_stat]] - 1);
-
-	/* Not enough mana to cast */
-	if (use_mana > p_ptr->csp)
-	{
-		chance += 5 * (use_mana - p_ptr->csp);
-	}
-
-	/* Extract the minimum failure rate */
-	minfail = adj_mag_fail[p_ptr->stat_ind[mp_ptr->spell_stat]];
-
-	/*
-	 * Non mage/priest characters never get too good
-	 * (added high mage, mindcrafter)
-	 */
-	if ((p_ptr->pclass != CLASS_PRIEST) &&
-	    (p_ptr->pclass != CLASS_MAGE) &&
-	    (p_ptr->pclass != CLASS_MINDCRAFTER) &&
-	    (p_ptr->pclass != CLASS_HIGH_MAGE))
-	{
-		if (minfail < 5) minfail = 5;
-	}
-
-	/* Hack -- Priest prayer penalty for "edged" weapons  -DGK */
-	if ((p_ptr->pclass == CLASS_PRIEST) && p_ptr->icky_wield) chance += 25;
-
-	if (p_ptr->dec_mana) chance -= 2;
-
-	/* Minimum failure rate */
-	if (chance < minfail) chance = minfail;
-
-	/* Stunning makes spells harder */
-	if (p_ptr->stun > 50) chance += 25;
-	else if (p_ptr->stun) chance += 15;
-
-	/* Always a 5 percent chance of working */
-	if (chance > 95) chance = 95;
-
-	if (p_ptr->dec_mana) chance--;
-
-	chance = MAX(chance, 0);
+	chance = get_spell_chance(s_ptr->sfail, s_ptr->slevel, use_mana);
 
 	/* Return the chance */
 	return (chance);
@@ -4071,7 +3997,7 @@ int inven_damage(inven_func typ, int perc)
 			if (amt)
 			{
 				/* Get a description */
-				object_desc(o_name, o_ptr, FALSE, 3);
+				object_desc(o_name, o_ptr, OD_OMIT_PREFIX);
 
 				/* Message */
 #ifdef JP
@@ -4151,7 +4077,7 @@ static int minus_ac(void)
 
 
 	/* Describe */
-	object_desc(o_name, o_ptr, FALSE, 0);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 	/* Extract the flags */
 	object_flags(o_ptr, &f1, &f2, &f3);
@@ -4349,7 +4275,7 @@ s = "ߤǤΤޤ";
 
 
 	/* Description */
-	object_desc(o_name, o_ptr, FALSE, 0);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 	o_ptr->art_flags3 |= TR3_IGNORE_ACID;
 
@@ -4397,7 +4323,7 @@ bool curse_armor(void)
 
 
 	/* Describe */
-	object_desc(o_name, o_ptr, FALSE, 3);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX);
 
 	/* Attempt a saving throw for artifacts */
 	if ((o_ptr->art_name || artifact_p(o_ptr)) && (randint0(100) < 50))
@@ -4474,7 +4400,7 @@ bool curse_weapon(void)
 
 
 	/* Describe */
-	object_desc(o_name, o_ptr, FALSE, 3);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX);
 
 	/* Attempt a saving throw */
 	if ((artifact_p(o_ptr) || o_ptr->art_name) && (randint0(100) < 50))
