@@ -925,11 +925,13 @@ static bool store_object_similar(object_type *o_ptr, object_type *j_ptr)
  */
 static void store_object_absorb(object_type *o_ptr, object_type *j_ptr)
 {
+	int max_num = (o_ptr->tval == TV_ROD) ?
+		MIN(99, MAX_SHORT / k_info[o_ptr->k_idx].pval) : 99;
 	int total = o_ptr->number + j_ptr->number;
-	int diff = (total > 99) ? total - 99 : 0;
+	int diff = (total > max_num) ? total - max_num : 0;
 
 	/* Combine quantity, lose excess items */
-	o_ptr->number = (total > 99) ? 99 : total;
+	o_ptr->number = (total > max_num) ? max_num : total;
 
 	/* Hack -- if rods are stacking, add the pvals (maximum timeouts) together. -LM- */
 	if (o_ptr->tval == TV_ROD)
@@ -1116,7 +1118,7 @@ static bool store_will_buy(object_type *o_ptr)
 						if (r_ptr->flags3 & RF3_ANIMAL) break;
 
 						/* Accept mimics */
-						if (strchr("?!", r_ptr->d_char)) break;
+						if (my_strchr("?!", r_ptr->d_char)) break;
 					}
 				}
 				case TV_POLEARM:
@@ -1211,6 +1213,153 @@ static bool store_will_buy(object_type *o_ptr)
 }
 
 
+/*
+ * Combine and reorder items in the home
+ */
+bool combine_and_reorder_home(void)
+{
+	int         i, j, k;
+	s32b        o_value;
+	object_type forge, *o_ptr, *j_ptr;
+	bool        flag = FALSE, combined;
+	store_type  *old_st_ptr = st_ptr;
+
+	st_ptr = &town[1].store[STORE_HOME];
+
+	do
+	{
+		combined = FALSE;
+
+		/* Combine the items in the home (backwards) */
+		for (i = st_ptr->stock_num - 1; i > 0; i--)
+		{
+			/* Get the item */
+			o_ptr = &st_ptr->stock[i];
+
+			/* Skip empty items */
+			if (!o_ptr->k_idx) continue;
+
+			/* Scan the items above that item */
+			for (j = 0; j < i; j++)
+			{
+				int max_num;
+
+				/* Get the item */
+				j_ptr = &st_ptr->stock[j];
+
+				/* Skip empty items */
+				if (!j_ptr->k_idx) continue;
+
+				/*
+				 * Get maximum number of the stack if these
+				 * are similar, get zero otherwise.
+				 */
+				max_num = object_similar_part(j_ptr, o_ptr);
+
+				/* Can we (partialy) drop "o_ptr" onto "j_ptr"? */
+				if (max_num && j_ptr->number < max_num)
+				{
+					if (o_ptr->number + j_ptr->number <= max_num)
+					{
+						/* Add together the item counts */
+						object_absorb(j_ptr, o_ptr);
+
+						/* One object is gone */
+						st_ptr->stock_num--;
+
+						/* Slide everything down */
+						for (k = i; k < st_ptr->stock_num; k++)
+						{
+							/* Structure copy */
+							st_ptr->stock[k] = st_ptr->stock[k + 1];
+						}
+
+						/* Erase the "final" slot */
+						object_wipe(&st_ptr->stock[k]);
+					}
+					else
+					{
+						int old_num = o_ptr->number;
+						int remain = j_ptr->number + o_ptr->number - max_num;
+
+						/* Add together the item counts */
+						object_absorb(j_ptr, o_ptr);
+
+						o_ptr->number = remain;
+
+						/* Hack -- if rods are stacking, add the pvals (maximum timeouts) and current timeouts together. -LM- */
+						if (o_ptr->tval == TV_ROD)
+						{
+							o_ptr->pval =  o_ptr->pval * remain / old_num;
+							o_ptr->timeout = o_ptr->timeout * remain / old_num;
+						}
+
+						/* Hack -- if wands are stacking, combine the charges. -LM- */
+						else if (o_ptr->tval == TV_WAND)
+						{
+							o_ptr->pval = o_ptr->pval * remain / old_num;
+						}
+					}
+
+					/* Take note */
+					combined = TRUE;
+
+					/* Done */
+					break;
+				}
+			}
+		}
+
+		flag |= combined;
+	}
+	while (combined);
+
+	/* Re-order the items in the home (forwards) */
+	for (i = 0; i < st_ptr->stock_num; i++)
+	{
+		/* Get the item */
+		o_ptr = &st_ptr->stock[i];
+
+		/* Skip empty slots */
+		if (!o_ptr->k_idx) continue;
+
+		/* Get the "value" of the item */
+		o_value = object_value(o_ptr);
+
+		/* Scan every occupied slot */
+		for (j = 0; j < st_ptr->stock_num; j++)
+		{
+			if (object_sort_comp(o_ptr, o_value, &st_ptr->stock[j])) break;
+		}
+
+		/* Never move down */
+		if (j >= i) continue;
+
+		/* Take note */
+		flag = TRUE;
+
+		/* Get local object */
+		j_ptr = &forge;
+
+		/* Save a copy of the moving item */
+		object_copy(j_ptr, &st_ptr->stock[i]);
+
+		/* Slide the objects */
+		for (k = i; k > j; k--)
+		{
+			/* Slide the item */
+			object_copy(&st_ptr->stock[k], &st_ptr->stock[k - 1]);
+		}
+
+		/* Insert the moving item */
+		object_copy(&st_ptr->stock[j], j_ptr);
+	}
+
+	st_ptr = old_st_ptr;
+
+	return flag;
+}
+
 
 /*
  * Add the item "o_ptr" to the inventory of the "Home"
@@ -1225,7 +1374,7 @@ static bool store_will_buy(object_type *o_ptr)
 static int home_carry(object_type *o_ptr)
 {
 	int 				slot;
-	s32b			   value, j_value;
+	s32b			   value;
 	int 	i;
 	object_type *j_ptr;
 
@@ -1256,45 +1405,7 @@ static int home_carry(object_type *o_ptr)
 	/* Check existing slots to see if we must "slide" */
 	for (slot = 0; slot < st_ptr->stock_num; slot++)
 	{
-		/* Get that item */
-		j_ptr = &st_ptr->stock[slot];
-
-		/* Hack -- readable books always come first */
-		if ((o_ptr->tval == REALM1_BOOK) &&
-			(j_ptr->tval != REALM1_BOOK)) break;
-		if ((j_ptr->tval == REALM1_BOOK) &&
-			(o_ptr->tval != REALM1_BOOK)) continue;
-
-		/* Objects sort by decreasing type */
-		if (o_ptr->tval > j_ptr->tval) break;
-		if (o_ptr->tval < j_ptr->tval) continue;
-
-		/* Can happen in the home */
-		if (!object_aware_p(o_ptr)) continue;
-		if (!object_aware_p(j_ptr)) break;
-
-		/* Objects sort by increasing sval */
-		if (o_ptr->sval < j_ptr->sval) break;
-		if (o_ptr->sval > j_ptr->sval) continue;
-
-		/* Objects in the home can be unknown */
-		if (!object_known_p(o_ptr)) continue;
-		if (!object_known_p(j_ptr)) break;
-
-		/*
-		 * Hack:  otherwise identical rods sort by
-		 * increasing recharge time --dsb
-		 */
-		if (o_ptr->tval == TV_ROD)
-		{
-			if (o_ptr->pval < j_ptr->pval) break;
-			if (o_ptr->pval > j_ptr->pval) continue;
-		}
-
-		/* Objects sort by decreasing value */
-		j_value = object_value(j_ptr);
-		if (value > j_value) break;
-		if (value < j_value) continue;
+		if (object_sort_comp(o_ptr, value, &st_ptr->stock[slot])) break;
 	}
 
 	/* Slide the others up */
@@ -1309,6 +1420,8 @@ static int home_carry(object_type *o_ptr)
 	/* Insert the new item */
 	st_ptr->stock[slot] = *o_ptr;
 
+	(void)combine_and_reorder_home();
+
 	/* Return the location */
 	return (slot);
 }
@@ -1623,7 +1736,7 @@ static void store_create(void)
 		object_known(q_ptr);
 
 		/* Mark it storebought */
-		q_ptr->ident |= IDENT_STOREB;
+		q_ptr->ident |= IDENT_STORE;
 
 		/* Mega-Hack -- no chests in stores */
 		if (q_ptr->tval == TV_CHEST) continue;
@@ -1731,7 +1844,7 @@ static void display_entry(int pos)
 	char		out_val[160];
 
 
-	int maxwid = 75;
+	int maxwid;
 
 	/* Get the item */
 	o_ptr = &st_ptr->stock[pos];
@@ -1754,13 +1867,9 @@ static void display_entry(int pos)
 			a |= 0x40;
 #endif
 
-		Term_draw(cur_col, i + 6, a, c);
-		if (use_bigtile)
-		{
-			cur_col++;
-			if (a & 0x80)
-				Term_draw(cur_col, i + 6, 255, -1);
-		}
+		Term_queue_bigchar(cur_col, i + 6, a, c, 0, 0);
+		if (use_bigtile) cur_col++;
+
 		cur_col += 2;
 	}
 
@@ -1773,7 +1882,7 @@ static void display_entry(int pos)
 		if (show_weights) maxwid -= 10;
 
 		/* Describe the object */
-		object_desc(o_name, o_ptr, TRUE, 3);
+		object_desc(o_name, o_ptr, 0);
 		o_name[maxwid] = '\0';
 		c_put_str(tval_to_attr[o_ptr->tval], o_name, i+6, cur_col);
 
@@ -1803,7 +1912,7 @@ static void display_entry(int pos)
 		if (show_weights) maxwid -= 7;
 
 		/* Describe the object (fully) */
-		object_desc_store(o_name, o_ptr, TRUE, 3);
+		object_desc(o_name, o_ptr, 0);
 		o_name[maxwid] = '\0';
 		c_put_str(tval_to_attr[o_ptr->tval], o_name, i+6, cur_col);
 
@@ -1984,14 +2093,9 @@ static void display_store(void)
 	{
 		cptr store_name = (f_name + f_info[FEAT_SHOP_HEAD + cur_store_num].name);
 		cptr owner_name = (ot_ptr->owner_name);
-		cptr race_name = race_info[ot_ptr->owner_race].title;
 
-		/* Put the owner name and race */
-#if 0
-		sprintf(buf, "%s (%s)", owner_name, race_name);
-#else
+		/* Put the owner name */
 		sprintf(buf, "%s", owner_name);
-#endif
 		put_str(buf, 3, 10);
 
 		/* Show the max price in the store (above prices) */
@@ -2248,11 +2352,25 @@ static int get_haggle(cptr pmt, s32b *poffer, s32b price, int final)
 	/* Ask until done */
 	while (TRUE)
 	{
+		bool res;
+
+		/* Display prompt */
+		prt(buf, 0, 0);
+
 		/* Default */
 		strcpy(out_val, "");
 
-		/* Ask the user for a response */
-		if (!get_string(buf, out_val, 32)) return (FALSE);
+		/*
+		 * Ask the user for a response.
+		 * Don't allow to use numpad as cursor key.
+		 */
+		res = askfor_aux(out_val, 32, FALSE);
+
+		/* Clear prompt */
+		prt("", 0, 0);
+
+		/* Cancelled */
+		if (!res) return FALSE;
 
 		/* Skip leading spaces */
 		for (p = out_val; *p == ' '; p++) /* loop */;
@@ -2573,7 +2691,7 @@ static bool purchase_haggle(object_type *o_ptr, s32b *price)
 static bool sell_haggle(object_type *o_ptr, s32b *price)
 {
 	s32b    purse, cur_ask, final_ask;
-	s32b    last_offer = 0, offer = 0;
+	s32b    last_offer, offer = 0;
 	s32b    x1, x2, x3;
 	s32b    min_per, max_per;
 	int     flag, loop_flag, noneed;
@@ -2980,7 +3098,7 @@ msg_format("ĤˤĤ $%ldǤ", (long)(best));
 		else
 		{
 			/* Describe the object (fully) */
-			object_desc_store(o_name, j_ptr, TRUE, 3);
+			object_desc(o_name, j_ptr, 0);
 
 			/* Message */
 #ifdef JP
@@ -3008,8 +3126,6 @@ msg_format("%s(%c)롣", o_name, I2A(item));
 			/* Player can afford it */
 			if (p_ptr->au >= price)
 			{
-				int idx;
-
 				/* Say "okay" */
 				say_comment_1();
 
@@ -3032,7 +3148,7 @@ msg_format("%s(%c)롣", o_name, I2A(item));
 				j_ptr->ident &= ~(IDENT_FIXED);
 
 				/* Describe the transaction */
-				object_desc(o_name, j_ptr, TRUE, 3);
+				object_desc(o_name, j_ptr, 0);
 
 				/* Message */
 #ifdef JP
@@ -3041,17 +3157,18 @@ msg_format("%s $%ldǹޤ", o_name, (long)price);
 				msg_format("You bought %s for %ld gold.", o_name, (long)price);
 #endif
 
-
 				/* Erase the inscription */
 				j_ptr->inscription = 0;
 
 				/* Erase the "feeling" */
 				j_ptr->feeling = FEEL_NONE;
+				j_ptr->ident &= ~(IDENT_STORE);
+
 				/* Give it to the player */
 				item_new = inven_carry(j_ptr);
 
 				/* Describe the final result */
-				object_desc(o_name, &inventory[item_new], TRUE, 3);
+				object_desc(o_name, &inventory[item_new], 0);
 
 				/* Message */
 #ifdef JP
@@ -3062,8 +3179,7 @@ msg_format("%s $%ldǹޤ", o_name, (long)price);
 #endif
 
 				/* Auto-inscription */
-				idx = is_autopick(&inventory[item_new]);
-				auto_inscribe_item(item_new, idx);
+				autopick_alter_item(item_new, FALSE);
 
 				/* Now, reduce the original stack's pval. */
 				if ((o_ptr->tval == TV_ROD) || (o_ptr->tval == TV_WAND))
@@ -3160,6 +3276,8 @@ msg_format("%s $%ldǹޤ", o_name, (long)price);
 	/* Home is much easier */
 	else
 	{
+		bool combined_or_reordered;
+
 		/* Distribute charges of wands/rods */
 		distribute_charges(o_ptr, j_ptr, amt);
 
@@ -3167,7 +3285,7 @@ msg_format("%s $%ldǹޤ", o_name, (long)price);
 		item_new = inven_carry(j_ptr);
 
 		/* Describe just the result */
-		object_desc(o_name, &inventory[item_new], TRUE, 3);
+		object_desc(o_name, &inventory[item_new], 0);
 
 		/* Message */
 #ifdef JP
@@ -3187,11 +3305,16 @@ msg_format("%s $%ldǹޤ", o_name, (long)price);
 		store_item_increase(item, -amt);
 		store_item_optimize(item);
 
+		combined_or_reordered = combine_and_reorder_home();
+
 		/* Hack -- Item is still here */
 		if (i == st_ptr->stock_num)
 		{
+			/* Redraw everything */
+			if (combined_or_reordered) display_inventory();
+
 			/* Redraw the item */
-			display_entry(item);
+			else display_entry(item);
 		}
 
 		/* The item is gone */
@@ -3331,7 +3454,7 @@ static void store_sell(void)
 	}
 
 	/* Get a full description */
-	object_desc(o_name, q_ptr, TRUE, 3);
+	object_desc(o_name, q_ptr, 0);
 
 	/* Remove any inscription, feeling for stores */
 	if (cur_store_num != STORE_HOME)
@@ -3412,6 +3535,9 @@ static void store_sell(void)
 			/* Modify quantity */
 			q_ptr->number = amt;
 
+			/* Make it look like to be known */
+			q_ptr->ident |= IDENT_STORE;
+
 			/*
 			 * Hack -- If a rod or wand, let the shopkeeper know just
 			 * how many charges he really paid for. -LM-
@@ -3425,7 +3551,7 @@ static void store_sell(void)
 			value = object_value(q_ptr) * q_ptr->number;
 
 			/* Get the description all over again */
-			object_desc(o_name, q_ptr, TRUE, 3);
+			object_desc(o_name, q_ptr, 0);
 
 			/* Describe the result (in message buffer) */
 #ifdef JP
@@ -3453,6 +3579,10 @@ msg_format("%s $%ldѤޤ", o_name, (long)price);
 			/* Take the item from the player, describe the result */
 			inven_item_increase(item, -amt);
 			inven_item_describe(item);
+
+			/* If items remain, auto-inscribe before optimizing */
+			if (o_ptr->number > 0) autopick_alter_item(item, FALSE);
+
 			inven_item_optimize(item);
 
 			/* Handle stuff */
@@ -3575,7 +3705,7 @@ msg_print("ΥƥˤĤäΤäƤ뤳ȤϤʤ");
 	}
 
 	/* Description */
-	object_desc(o_name, o_ptr, TRUE, 3);
+	object_desc(o_name, o_ptr, 0);
 
 	/* Describe */
 #ifdef JP
@@ -3877,6 +4007,9 @@ static void store_process_command(void)
 		case '=':
 		{
 			do_cmd_options();
+			(void)combine_and_reorder_home();
+			do_cmd_redraw();
+			display_store();
 			break;
 		}
 
@@ -4242,7 +4375,7 @@ void do_cmd_store(void)
 				object_copy(q_ptr, o_ptr);
 
 				/* Describe it */
-				object_desc(o_name, q_ptr, TRUE, 3);
+				object_desc(o_name, q_ptr, 0);
 
 				/* Message */
 #ifdef JP
@@ -4390,8 +4523,6 @@ void store_maint(int town_num, int store_num)
 {
 	int 		j;
 
-	int 	old_rating = rating;
-
 	cur_store_num = store_num;
 
 	/* Ignore home */
@@ -4461,10 +4592,6 @@ void store_maint(int town_num, int store_num)
 
 	/* Acquire some new items */
 	while (st_ptr->stock_num < j) store_create();
-
-
-	/* Hack -- Restore the rating */
-	rating = old_rating;
 }
 
 
@@ -4518,7 +4645,7 @@ void move_to_black_market(object_type *o_ptr)
 
 	st_ptr = &town[p_ptr->town_num].store[STORE_BLACK];
 
-	o_ptr->ident |= IDENT_STOREB;
+	o_ptr->ident |= IDENT_STORE;
 
 	(void)store_carry(o_ptr);
 
