@@ -433,6 +433,9 @@ static void generate_wilderness_area(int terrain, u32b seed, bool border, bool c
 	int table_size = sizeof(terrain_table[0]) / sizeof(int);
 	int roughness = 1; /* The roughness of the level. */
 
+	/* Unused */
+	(void)border;
+
 	/* The outer wall is easy */
 	if (terrain == TERRAIN_EDGE)
 	{
@@ -801,7 +804,6 @@ void wilderness_gen(void)
 	}
 
 	player_place(p_ptr->oldpy, p_ptr->oldpx);
-	p_ptr->leftbldg = FALSE;
 	p_ptr->leaving_dungeon = FALSE;
 
 	/* Make some residents */
@@ -842,10 +844,13 @@ static wilderness_grid w_letter[255];
  */
 errr parse_line_wilderness(char *buf, int ymin, int xmin, int ymax, int xmax, int *y, int *x)
 {
-
 	int i, num;
 	char *zz[33];
 
+	/* Unused */
+	(void)ymin;
+	(void)ymax;
+
 	/* Paranoia */
 	if (!(buf[0] == 'W')) return (PARSE_ERROR_GENERIC);
 
