@@ -223,7 +223,7 @@ static void kind_info(char *buf, char *dam, char *wgt, int *lev, s32b *val, int
 
 
 	/* Description (too brief) */
-	object_desc_store(buf, q_ptr, FALSE, 0);
+	object_desc(buf, q_ptr, OD_NAME_ONLY | OD_STORE);
 
 
 	/* Misc info */
@@ -915,7 +915,7 @@ static cptr *spoiler_flag_aux(const u32b art_flags, const flag_desc *flag_ptr,
 static void analyze_general (object_type *o_ptr, char *desc_ptr)
 {
 	/* Get a "useful" description of the object */
-	object_desc_store(desc_ptr, o_ptr, TRUE, 1);
+	object_desc(desc_ptr, o_ptr, OD_NAME_AND_ENCHANT | OD_STORE);
 }
 
 
@@ -946,7 +946,8 @@ static void analyze_pval (object_type *o_ptr, pval_info_type *p_ptr)
 	affects_list = p_ptr->pval_affects;
 
 	/* Create the "+N" string */
-	sprintf(p_ptr->pval_desc, "%s%d", POSITIZE(o_ptr->pval), o_ptr->pval);
+	sprintf(p_ptr->pval_desc, "%s%d", POSITIZE(o_ptr->pval), 
+		(int)(o_ptr->pval));
 
 	/* First, check to see if the pval affects all stats */
 	if ((f1 & all_stats) == all_stats)
@@ -1114,42 +1115,38 @@ static void analyze_misc_magic (object_type *o_ptr, cptr *misc_list)
 	 * being "lightly cursed".
 	 */
 
-/*	if (cursed_p(o_ptr)) */
-	if (1)
+	if (f3 & TR3_TY_CURSE)
 	{
-		if (f3 & TR3_TY_CURSE)
-		{
 #ifdef JP
-			*misc_list++ = "Ťαǰ";
+		*misc_list++ = "Ťαǰ";
 #else
-			*misc_list++ = "Ancient Curse";
+		*misc_list++ = "Ancient Curse";
 #endif
-		}
-		if (f3 & TR3_PERMA_CURSE)
-		{
+	}
+
+	if (f3 & TR3_PERMA_CURSE)
+	{
 #ifdef JP
-			*misc_list++ = "ʱμ";
+		*misc_list++ = "ʱμ";
 #else
-			*misc_list++ = "Permanently Cursed";
+		*misc_list++ = "Permanently Cursed";
 #endif
-		}
-		else if (f3 & TR3_HEAVY_CURSE)
-		{
+	}
+	else if (f3 & TR3_HEAVY_CURSE)
+	{
 #ifdef JP
-			*misc_list++ = "Ϥʼ";
+		*misc_list++ = "Ϥʼ";
 #else
-			*misc_list++ = "Heavily Cursed";
+		*misc_list++ = "Heavily Cursed";
 #endif
-		}
-/*		else */
-		else if (f3 & TR3_CURSED)
-		{
+	}
+	else if (f3 & TR3_CURSED)
+	{
 #ifdef JP
-			*misc_list++ = "";
+		*misc_list++ = "";
 #else
-			*misc_list++ = "Cursed";
+		*misc_list++ = "Cursed";
 #endif
-		}
 	}
 
 	/* Terminate the description list */
@@ -1840,7 +1837,7 @@ static void spoil_mon_info(cptr fname)
 {
 	char buf[1024];
 	int msex, vn, i, j, k, n, count = 0;
-	bool breath, magic, sin;
+	bool breath, magic;
 	cptr p, q;
 	cptr vp[64];
 	u32b flags1, flags2, flags3, flags4, flags5, flags6;
@@ -1850,6 +1847,8 @@ static void spoil_mon_info(cptr fname)
 
 #ifdef JP
 	char            jverb_buf[64];
+#else
+	bool sin;
 #endif
 
 	/* Build the filename */
@@ -2888,11 +2887,11 @@ static void spoil_mon_info(cptr fname)
 		/* Drops gold and/or items */
 		if (i)
 		{
-			sin = FALSE;
 #ifdef JP
 			sprintf(buf, "%s", wd_che[msex]);
 #else
 			sprintf(buf, "%s will carry", wd_che[msex]);
+			sin = FALSE;
 #endif
 			spoil_out(buf);
 
