@@ -534,7 +534,7 @@ static void wiz_display_item(object_type *o_ptr)
 	prt_alloc(o_ptr->tval, o_ptr->sval, 1, 0);
 
 	/* Describe fully */
-	object_desc_store(buf, o_ptr, TRUE, 3);
+	object_desc(buf, o_ptr, OD_STORE);
 
 	prt(buf, 2, j);
 
@@ -621,7 +621,7 @@ static tval_desc tvals[] =
 	{ TV_POTION,            ""                   },
 	{ TV_SCROLL,            "ʪ"                 },
 	{ TV_WAND,              ""               },
-	{ TV_STAFF,             ""                   },
+	{ TV_STAFF,             "å"             },
 	{ TV_ROD,               "å"               },
 	{ TV_LIFE_BOOK,         "ˡ(̿)"         },
 	{ TV_SORCERY_BOOK,      "ˡ()"         },
@@ -683,7 +683,7 @@ static tval_desc tvals[] =
 /*
  * Strip an "object name" into a buffer
  */
-static void strip_name(char *buf, int k_idx)
+void strip_name(char *buf, int k_idx)
 {
 	char *t;
 
@@ -826,7 +826,7 @@ static void wiz_tweak_item(object_type *o_ptr)
 
 
 	p = "Enter new 'pval' setting: ";
-	sprintf(tmp_val, "%d", o_ptr->pval);
+	sprintf(tmp_val, "%d", (int)(o_ptr->pval));
 	if (!get_string(p, tmp_val, 5)) return;
 	o_ptr->pval = atoi(tmp_val);
 	wiz_display_item(o_ptr);
@@ -867,7 +867,7 @@ static void wiz_reroll_item(object_type *o_ptr)
 
 	char ch;
 
-	bool changed = FALSE;
+	bool changed;
 
 
 	/* Hack -- leave artifacts alone */
@@ -1068,8 +1068,6 @@ static void wiz_statistics(object_type *o_ptr)
 		}
 		else
 		{
-			good = FALSE;
-			great = FALSE;
 			break;
 		}
 
@@ -1257,10 +1255,6 @@ static void do_cmd_wiz_play(void)
 	}
 
 
-	/* The item was not changed */
-	changed = FALSE;
-
-
 	/* Save the screen */
 	screen_save();
 
@@ -1505,7 +1499,6 @@ static void do_cmd_wiz_jump(void)
 	leave_quest_check();
 
 	p_ptr->inside_quest = 0;
-	p_ptr->leftbldg = FALSE;
 
 	/* Leaving */
 	p_ptr->leaving = TRUE;
@@ -1564,28 +1557,7 @@ static void do_cmd_wiz_summon(int num)
  */
 static void do_cmd_wiz_named(int r_idx, bool slp)
 {
-	int i, x, y;
-
-	/* Paranoia */
-	/* if (!r_idx) return; */
-
-	/* Prevent illegal monsters */
-	if (r_idx >= max_r_idx) return;
-
-	/* Try 10 times */
-	for (i = 0; i < 10; i++)
-	{
-		int d = 1;
-
-		/* Pick a location */
-		scatter(&y, &x, py, px, d, 0);
-
-		/* Require empty grids */
-		if (!cave_empty_bold(y, x)) continue;
-
-		/* Place it (allow groups) */
-		if (place_monster_aux(y, x, r_idx, slp, TRUE, FALSE, FALSE)) break;
-	}
+	(void)summon_named_creature(py, px, r_idx, slp, TRUE, FALSE);
 }
 
 
@@ -1596,7 +1568,7 @@ static void do_cmd_wiz_named(int r_idx, bool slp)
  */
 static void do_cmd_wiz_named_friendly(int r_idx, bool slp)
 {
-	(void) summon_named_creature(py, px, r_idx, slp, TRUE, TRUE);
+	(void)summon_named_creature(py, px, r_idx, slp, TRUE, TRUE);
 }
 
 
@@ -1643,6 +1615,91 @@ static void do_cmd_wiz_zap_all(void)
 }
 
 
+#define NUM_O_SET 8
+#define NUM_O_BIT 32
+
+/*
+ * Hack -- Dump option bits usage
+ */
+static void do_cmd_dump_options(void)
+{
+	int  i, j;
+	FILE *fff;
+	char buf[1024];
+	int  **exist;
+
+	/* Build the filename */
+	path_build(buf, sizeof buf, ANGBAND_DIR_USER, "opt_info.txt");
+
+	/* File type is "TEXT" */
+	FILE_TYPE(FILE_TYPE_TEXT);
+
+	/* Open the file */
+	fff = my_fopen(buf, "a");
+
+	/* Oops */
+	if (!fff)
+	{
+#ifdef JP
+		msg_format("ե %s 򳫤ޤǤ", buf);
+#else
+		msg_format("Failed to open file %s.", buf);
+#endif
+		msg_print(NULL);
+		return;
+	}
+
+	/* Allocate the "exist" array (2-dimension) */
+	C_MAKE(exist, NUM_O_SET, int *);
+	C_MAKE(*exist, NUM_O_BIT * NUM_O_SET, int);
+	for (i = 1; i < NUM_O_SET; i++) exist[i] = *exist + i * NUM_O_BIT;
+
+	/* Check for exist option bits */
+	for (i = 0; option_info[i].o_desc; i++)
+	{
+		option_type *ot_ptr = &option_info[i];
+		if (ot_ptr->o_var) exist[ot_ptr->o_set][ot_ptr->o_bit] = i + 1;
+	}
+
+	fprintf(fff, "[Option bits usage on XAngband %d.%d.%d]\n\n",
+	        FAKE_VER_MAJOR, FAKE_VER_MINOR, FAKE_VER_PATCH);
+
+	fputs("Set - Bit (Page) Option Name\n", fff);
+	fputs("------------------------------------------------\n", fff);
+	/* Dump option bits usage */
+	for (i = 0; i < NUM_O_SET; i++)
+	{
+		for (j = 0; j < NUM_O_BIT; j++)
+		{
+			if (exist[i][j])
+			{
+				option_type *ot_ptr = &option_info[exist[i][j] - 1];
+				fprintf(fff, "  %d -  %02d (%4d) %s\n",
+				        i, j, ot_ptr->o_page, ot_ptr->o_text);
+			}
+			else
+			{
+				fprintf(fff, "  %d -  %02d\n", i, j);
+			}
+		}
+		fputc('\n', fff);
+	}
+
+	/* Free the "exist" array (2-dimension) */
+	C_KILL(*exist, NUM_O_BIT * NUM_O_SET, int);
+	C_KILL(exist, NUM_O_SET, int *);
+
+	/* Close it */
+	my_fclose(fff);
+
+#ifdef JP
+	msg_format("ץbitѾե %s ˽񤭽Фޤ", buf);
+#else
+	msg_format("Option bits usage dump saved to file %s.", buf);
+#endif
+}
+
+
 #ifdef ALLOW_SPOILERS
 
 /*
@@ -1670,33 +1727,30 @@ void do_cmd_debug(void)
 	int     x, y;
 	char    cmd;
 
-
 	/* Get a "debug command" */
 	get_com("Debug Command: ", &cmd);
 
 	/* Analyze the command */
 	switch (cmd)
 	{
-		/* Nothing */
-		case ESCAPE:
-		case ' ':
-		case '\n':
-		case '\r':
+	/* Nothing */
+	case ESCAPE:
+	case ' ':
+	case '\n':
+	case '\r':
 		break;
 
-
 #ifdef ALLOW_SPOILERS
 
-		/* Hack -- Generate Spoilers */
-		case '"':
+	/* Hack -- Generate Spoilers */
+	case '"':
 		do_cmd_spoilers();
 		break;
 
 #endif /* ALLOW_SPOILERS */
 
-
-		/* Hack -- Help */
-		case '?':
+	/* Hack -- Help */
+	case '?':
 		screen_save();
 #ifdef JP
 		show_file("jwizard.txt", NULL, 0 , 0);
@@ -1706,216 +1760,212 @@ void do_cmd_debug(void)
 		screen_load();
 		break;
 
-		/* Cure all maladies */
-		case 'a':
+	/* Cure all maladies */
+	case 'a':
 		do_cmd_wiz_cure_all();
 		break;
 
-		/* Know alignment */
-		case 'A':
+	/* Know alignment */
+	case 'A':
 		msg_format("Your alignment is %d.", p_ptr->align);
 		break;
 
-		/* Teleport to target */
-		case 'b':
+	/* Teleport to target */
+	case 'b':
 		do_cmd_wiz_bamf();
 		break;
 
-		/* Create any object */
-		case 'c':
+	/* Create any object */
+	case 'c':
 		wiz_create_item();
 		break;
 
-		/* Create a named artifact */
-		case 'C':
+	/* Create a named artifact */
+	case 'C':
 		wiz_create_named_art(command_arg);
 		break;
 
-		/* Detect everything */
-		case 'd':
-		detect_all(DETECT_RAD_DEFAULT*3);
+	/* Detect everything */
+	case 'd':
+		detect_all(DETECT_RAD_ALL);
 		break;
 
-		/* Dimension_door */
-		case 'D':
+	/* Dimension_door */
+	case 'D':
 		wiz_dimension_door();
 		break;
 
-		/* Edit character */
-		case 'e':
+	/* Edit character */
+	case 'e':
 		do_cmd_wiz_change();
 		break;
 
-		/* View item info */
-		case 'f':
-		identify_fully(FALSE);
+	/* View item info */
+	case 'f':
+		(void)identify_fully();
 		break;
 
-		/* Create feature */
-		case 'F':
+	/* Create feature */
+	case 'F':
 		if (command_arg > 0) do_cmd_wiz_feature(command_arg);
 		break;
 
-		/* Good Objects */
-		case 'g':
+	/* Good Objects */
+	case 'g':
 		if (command_arg <= 0) command_arg = 1;
 		acquirement(py, px, command_arg, FALSE, TRUE);
 		break;
 
-		/* Hitpoint rerating */
-		case 'h':
-		do_cmd_rerate(TRUE); break;
-
-#ifdef MONSTER_HORDES
-		case 'H':
-		do_cmd_summon_horde(); break;
-#endif /* MONSTER_HORDES */
-
-		/* Identify */
-		case 'i':
-		(void)ident_spell(FALSE);
+	/* Hitpoint rerating */
+	case 'h':
+		do_cmd_rerate(TRUE);
 		break;
 
-		/* Go up or down in the dungeon */
-		case 'j':
+#ifdef MONSTER_HORDES
+	case 'H':
+		do_cmd_summon_horde();
+		break;
+#endif /* MONSTER_HORDES */
+
+	/* Identify */
+	case 'i':
+		(void)ident_spell();
+		break;
+
+	/* Go up or down in the dungeon */
+	case 'j':
 		do_cmd_wiz_jump();
 		break;
 
-		/* Self-Knowledge */
-		case 'k':
-			self_knowledge();
-			break;
+	/* Self-Knowledge */
+	case 'k':
+		self_knowledge();
+		break;
 
-		/* Learn about objects */
-		case 'l':
-			do_cmd_wiz_learn();
-			break;
+	/* Learn about objects */
+	case 'l':
+		do_cmd_wiz_learn();
+		break;
 
-		/* Magic Mapping */
-		case 'm':
-			map_area(DETECT_RAD_MAP);
-			break;
+	/* Magic Mapping */
+	case 'm':
+		map_area(DETECT_RAD_ALL);
+		break;
 
-		/* Mutation */
-		case 'M':
-			(void)gain_random_mutation(command_arg);
-			break;
+	/* Mutation */
+	case 'M':
+		(void)gain_random_mutation(command_arg);
+		break;
 
-		/* Lose Mutation */
-		case 'L':
-			if (p_ptr->muta)
-			{
-				while(!lose_mutation(0));
-			}
-			break;
+	/* Lose Mutation */
+	case 'L':
+		if (p_ptr->muta)
+		{
+			while (!lose_mutation(0));
+		}
+		break;
 
-		/* Summon _friendly_ named monster */
-		case 'N':
-			do_cmd_wiz_named_friendly(command_arg, TRUE);
-			break;
+	/* Summon _friendly_ named monster */
+	case 'N':
+		do_cmd_wiz_named_friendly(command_arg, TRUE);
+		break;
 
-		/* Summon Named Monster */
-		case 'n':
-			do_cmd_wiz_named(command_arg, TRUE);
-			break;
+	/* Summon Named Monster */
+	case 'n':
+		do_cmd_wiz_named(command_arg, TRUE);
+		break;
 
-		/* Object playing routines */
-		case 'o':
-			do_cmd_wiz_play();
-			break;
+	/* Dump option bits usage */
+	case 'O':
+		do_cmd_dump_options();
+		break;
 
-		/* Phase Door */
-		case 'p':
-			teleport_player(10);
-			break;
+	/* Object playing routines */
+	case 'o':
+		do_cmd_wiz_play();
+		break;
+
+	/* Phase Door */
+	case 'p':
+		teleport_player(10);
+		break;
 
 #if 0
-		/* Complete a Quest -KMW- */
-		case 'q':
+	/* Complete a Quest -KMW- */
+	case 'q':
+		for (i = 0; i < max_quests; i++)
 		{
-			for (i = 0; i < max_quests; i++)
+			if (p_ptr->quest[i].status == QUEST_STATUS_TAKEN)
 			{
-				if (p_ptr->quest[i].status == QUEST_STATUS_TAKEN)
-				{
-					p_ptr->quest[i].status++;
-					msg_print("Completed Quest");
-					msg_print(NULL);
-					break;
-				}
-			}
-			if (i == max_quests)
-			{
-				msg_print("No current quest");
+				p_ptr->quest[i].status++;
+				msg_print("Completed Quest");
 				msg_print(NULL);
+				break;
 			}
-			break;
 		}
+		if (i == max_quests)
+		{
+			msg_print("No current quest");
+			msg_print(NULL);
+		}
+		break;
 #endif
 
-		/* Make every dungeon square "known" to test streamers -KMW- */
-		case 'u':
+	/* Make every dungeon square "known" to test streamers -KMW- */
+	case 'u':
+		for (y = 0; y < cur_hgt; y++)
 		{
-			for (y = 0; y < cur_hgt; y++)
+			for (x = 0; x < cur_wid; x++)
 			{
-				for (x = 0; x < cur_wid; x++)
-				{
-					cave[y][x].info |= (CAVE_GLOW | CAVE_MARK);
-				}
+				cave[y][x].info |= (CAVE_GLOW | CAVE_MARK);
 			}
-			wiz_lite_aux(TRUE, TRUE);
-			break;
 		}
+		wiz_lite_aux(TRUE, TRUE);
+		break;
 
-		/* Summon Random Monster(s) */
-		case 's':
-			if (command_arg <= 0) command_arg = 1;
-			do_cmd_wiz_summon(command_arg);
-			break;
+	/* Summon Random Monster(s) */
+	case 's':
+		if (command_arg <= 0) command_arg = 1;
+		do_cmd_wiz_summon(command_arg);
+		break;
 
-		/* Teleport */
-		case 't':
-			teleport_player(100);
-			break;
+	/* Teleport */
+	case 't':
+		teleport_player(100);
+		break;
 
-		/* Very Good Objects */
-		case 'v':
-			if (command_arg <= 0) command_arg = 1;
-			acquirement(py, px, command_arg, TRUE, TRUE);
-			break;
+	/* Very Good Objects */
+	case 'v':
+		if (command_arg <= 0) command_arg = 1;
+		acquirement(py, px, command_arg, TRUE, TRUE);
+		break;
 
-		/* Wizard Light the Level */
-		case 'w':
+	/* Wizard Light the Level */
+	case 'w':
 		wiz_lite();
 		break;
 
-		/* Increase Experience */
-		case 'x':
-		if (command_arg)
-		{
-			gain_exp(command_arg);
-		}
-		else
-		{
-			gain_exp(p_ptr->exp + 1);
-		}
+	/* Increase Experience */
+	case 'x':
+		gain_exp(command_arg ? command_arg : (p_ptr->exp + 1));
 		break;
 
-		/* Zap Monsters (Genocide) */
-		case 'z':
+	/* Zap Monsters (Genocide) */
+	case 'z':
 		do_cmd_wiz_zap();
 		break;
 
-		case 'Z':
+	case 'Z':
 		do_cmd_wiz_zap_all();
 		break;
 
-		/* Hack -- whatever I desire */
-		case '_':
+	/* Hack -- whatever I desire */
+	case '_':
 		do_cmd_wiz_hack_ben();
 		break;
 
-		/* Not a Wizard Command */
-		default:
+	/* Not a Wizard Command */
+	default:
 		msg_print("That is not a valid debug command.");
 		break;
 	}
