@@ -119,13 +119,8 @@ void extract_day_hour_min(int *day, int *hour, int *min)
 	s32b len = 10 * TOWN_DAWN;
 	s32b tick = turn % len + len / 4;
 
-	if ((p_ptr->prace == RACE_VAMPIRE) ||
-	    (p_ptr->prace == RACE_SKELETON) ||
-	    (p_ptr->prace == RACE_ZOMBIE) ||
-	    (p_ptr->prace == RACE_SPECTRE))
-		*day = (turn - (10 * TOWN_DAWN * 3 / 4)) / len + 1;
-	else
-		*day = (turn + (10 * TOWN_DAWN / 4))/ len + 1;
+	/* We cannot choose undeads on birth, so initial turn is 1 */
+	*day = (turn + (10 * TOWN_DAWN / 4))/ len + 1;
 	*hour = (24 * tick / len) % 24;
 	*min = (1440 * tick / len) % 60;
 }
@@ -492,7 +487,7 @@ static void prt_status(void)
  */
 static void prt_title(void)
 {
-	cptr p = "";
+	cptr p;
 
 	/* Wizard */
 	if (wizard)
@@ -759,6 +754,7 @@ static void prt_depth(void)
 {
 	char depths[32];
 	int wid, hgt, row_depth, col_depth;
+	byte attr = TERM_WHITE;
 
 	Term_get_size(&wid, &hgt);
 	col_depth = wid + COL_DEPTH;
@@ -767,20 +763,18 @@ static void prt_depth(void)
 	if (p_ptr->inside_arena)
 	{
 #ifdef JP
-strcpy(depths, "꡼");
+		strcpy(depths, "꡼");
 #else
 		strcpy(depths, "Arena");
 #endif
-
 	}
 	else if (p_ptr->inside_quest && quest[p_ptr->inside_quest].type != QUEST_TYPE_RANDOM)
 	{
 #ifdef JP
-strcpy(depths, "");
+		strcpy(depths, "");
 #else
 		strcpy(depths, "Quest");
 #endif
-
 	}
 	else if (!dun_level)
 	{
@@ -788,33 +782,40 @@ strcpy(depths, "");
 			strcpy(depths, town[p_ptr->town_num].name);
 		else
 #ifdef JP
-strcpy(depths, "");
+			strcpy(depths, "");
 #else
 			strcpy(depths, "Wilderness");
 #endif
-
-	}
-	else if (depth_in_feet)
-	{
-#ifdef JP
-		(void)sprintf(depths, "%d ft", dun_level * 50);
-#else
-		(void)sprintf(depths, "%d ft", dun_level * 50);
-#endif
-
 	}
 	else
 	{
 #ifdef JP
-sprintf(depths, "ϲ %d ", dun_level);
+		if (depth_in_feet) (void)sprintf(depths, "%d ft", dun_level * 50);
+		else (void)sprintf(depths, "ϲ %d ", dun_level);
 #else
-		(void)sprintf(depths, "Lev %d", dun_level);
+		if (depth_in_feet) (void)sprintf(depths, "%d ft", dun_level * 50);
+		else (void)sprintf(depths, "Lev %d", dun_level);
 #endif
 
+		/* Get color of level based on feeling  -JSV- */
+		switch (p_ptr->feeling)
+		{
+		case  0: attr = TERM_SLATE;   break; /* Unknown */
+		case  1: attr = TERM_L_BLUE;  break; /* Special */
+		case  2: attr = TERM_VIOLET;  break; /* Horrible visions */
+		case  3: attr = TERM_RED;     break; /* Very dangerous */
+		case  4: attr = TERM_L_RED;   break; /* Very bad feeling */
+		case  5: attr = TERM_ORANGE;  break; /* Bad feeling */
+		case  6: attr = TERM_YELLOW;  break; /* Nervous */
+		case  7: attr = TERM_L_UMBER; break; /* Luck is turning */
+		case  8: attr = TERM_L_WHITE; break; /* Don't like */
+		case  9: attr = TERM_WHITE;   break; /* Reasonably safe */
+		case 10: attr = TERM_WHITE;   break; /* Boring place */
+		}
 	}
 
 	/* Right-Adjust the "depth", and clear old values */
-	prt(format("%12s", depths), row_depth, col_depth);
+	c_prt(attr, format("%12s", depths), row_depth, col_depth);
 }
 
 
@@ -1970,7 +1971,8 @@ static void calc_mana(void)
 	/* Hack -- Must be literate */
 	if (!mp_ptr->spell_type) return;
 
-	if (p_ptr->pclass == CLASS_MINDCRAFTER)
+	if ((p_ptr->pclass == CLASS_MINDCRAFTER) ||
+		(p_ptr->pclass == CLASS_ELEMENTALIST))
 	{
 		levels = p_ptr->lev;
 	}
@@ -2061,6 +2063,7 @@ static void calc_mana(void)
 				 * is 30 pounds over their weight limit. */
 				case CLASS_MAGE:
 				case CLASS_HIGH_MAGE:
+				case CLASS_ELEMENTALIST:
 				{
 					msp -= msp * (cur_wgt - max_wgt) / 600;
 					break;
@@ -2283,6 +2286,13 @@ static void calc_torch(void)
 				continue;
 			}
 
+			/* Feanorian lamps provide more lite */
+			if (o_ptr->sval == SV_LITE_FEANOR)
+			{
+				p_ptr->cur_lite += 2;
+				continue;
+			}
+
 			/* Artifact Lites provide permanent, bright, lite */
 			if (artifact_p(o_ptr))
 			{
@@ -2377,6 +2387,7 @@ static sint add_special_melee_skill(byte pclass, s16b weight, object_type *o_ptr
 		/* Mage/High Mage.  Can use 6 lb weapons without penalty at level 1, and 16 lb weapons without penalty at 50th level. */
 		case CLASS_MAGE:
 		case CLASS_HIGH_MAGE:
+		case CLASS_ELEMENTALIST:
 		{
 			add_skill = 20 + (2 * p_ptr->lev / 3) - (weight / 3);
 			if (add_skill > 0) add_skill = 0;
@@ -2466,7 +2477,7 @@ static sint add_special_melee_skill(byte pclass, s16b weight, object_type *o_ptr
 }
 
 /* Calculate all class and race-based bonuses and penalties to missile Skill -LM- */
-static sint add_special_missile_skill(byte pclass, s16b weight, object_type *o_ptr)
+static sint add_special_missile_skill(byte pclass)
 {
 	int add_skill = 0;
 
@@ -2510,6 +2521,7 @@ static sint add_special_missile_skill(byte pclass, s16b weight, object_type *o_p
 	return (add_skill);
 }
 
+
 /*
  * Calculate the players current "state", taking into account
  * not only race/class intrinsics, but also objects being worn
@@ -2692,6 +2704,9 @@ void calc_bonuses(void)
 			if (p_ptr->lev > 29) p_ptr->resist_conf = TRUE;
 			if (p_ptr->lev > 39) p_ptr->telepathy = TRUE;
 			break;
+		case CLASS_ELEMENTALIST:
+			element_bonuses();
+			break;
 		case CLASS_MONK:
 			/* Unencumbered Monks become faster every 10 levels */
 			if (!(monk_heavy_armor()))
@@ -3082,7 +3097,7 @@ void calc_bonuses(void)
 		if (f2 & (TR2_HOLD_LIFE))   p_ptr->hold_life = TRUE;
 		if (f3 & (TR3_WRAITH))      p_ptr->wraith_form = TRUE;
 		if (f3 & (TR3_WARNING))
-			if (!o_ptr->inscription || !(strchr(quark_str(o_ptr->inscription), '$')))
+			if (!o_ptr->inscription || !(my_strchr(quark_str(o_ptr->inscription), '$')))
 			{
 			     p_ptr->warning = TRUE;
 			}
@@ -3619,9 +3634,8 @@ void calc_bonuses(void)
 			}
 		}
 	}
-	/* Add all class and race-specific adjustments to missile Skill. -LM- */
-	p_ptr->skill_thb += add_special_missile_skill (p_ptr->pclass, o_ptr->weight,
-	 o_ptr);
+	/* Add all class-specific adjustments to missile Skill. -LM- */
+	p_ptr->skill_thb += add_special_missile_skill(p_ptr->pclass);
 
 
 	/* Examine the "main weapon" */
@@ -3650,8 +3664,7 @@ void calc_bonuses(void)
 		  !(p_ptr->pclass == CLASS_MONK && o_ptr->name1 == ART_XIAOLONG))
 	{
 		int str_index, dex_index;
-
-		int num = 0, wgt = 0, mul = 0, div = 0;
+		int num, wgt, mul, div;
 
 		/* Analyze the class */
 		switch (p_ptr->pclass)
@@ -3996,7 +4009,7 @@ void notice_stuff(void)
 	if (p_ptr->notice & (PN_AUTODESTROY))
 	{
 		p_ptr->notice &= ~(PN_AUTODESTROY);
-		delayed_auto_destroy();
+		autopick_delayed_alter();
 	}
 
 	/* Combine the pack */
