@@ -80,13 +80,9 @@ static void choice_gain_stat(void)
  */
 void check_experience(void)
 {
-	int		i;
 	bool level_mutation = FALSE;
 	bool inc_stat_okay = FALSE;
-
-
-	/* Note current level */
-	i = p_ptr->lev;
+	int  old_lev = p_ptr->lev;
 
 	/* Hack -- lower limit */
 	if (p_ptr->exp < 0) p_ptr->exp = 0;
@@ -224,6 +220,8 @@ void check_experience(void)
 	/* Handle stuff */
 	handle_stuff();
 
+	/* Load an autopick preference file */
+	if (old_lev != p_ptr->lev) autopick_load_pref(FALSE);
 }
 
 
@@ -408,6 +406,7 @@ void monster_death(int m_idx, bool drop_item_okay)
 			int d_side = r_ptr->blow[i].d_side;
 			int damage = damroll(d_dice, d_side);
 
+			sound(SOUND_EXPLODE);
 			project(m_idx, 3, y, x, damage, typ, flg);
 			break;
 		}
@@ -492,6 +491,7 @@ void monster_death(int m_idx, bool drop_item_okay)
 #else
 						msg_print("You just completed your quest!");
 #endif
+						sound(SOUND_QUEST);
 						msg_print(NULL);
 					}
 
@@ -539,6 +539,7 @@ void monster_death(int m_idx, bool drop_item_okay)
 #else
 						msg_print("You just completed your quest!");
 #endif
+						sound(SOUND_QUEST);
 						msg_print(NULL);
 					}
 				}
@@ -591,8 +592,8 @@ void monster_death(int m_idx, bool drop_item_okay)
 #else
 						msg_print("You just completed your quest!");
 #endif
+						sound(SOUND_QUEST);
 						msg_print(NULL);
-
 					}
 
 					/* Finish the two main quests without rewarding */
@@ -637,6 +638,7 @@ void monster_death(int m_idx, bool drop_item_okay)
 #else
 						msg_print("You just completed your quest!");
 #endif
+						sound(SOUND_QUEST);
 						msg_print(NULL);
 					}
 					quest[i].cur_num = 0;
@@ -768,7 +770,7 @@ void monster_death(int m_idx, bool drop_item_okay)
 			{
 				scatter(&wy, &wx, y, x, 20, 0);
 			}
-			while (!(in_bounds(wy, wx) && cave_floor_bold(wy, wx)) && --attempts);
+			while (!(in_bounds(wy, wx) && cave_empty_bold2(wy, wx)) && --attempts);
 
 			if (attempts > 0)
 			{
@@ -1211,6 +1213,9 @@ msg_print("ä(ޥ)Ƥ빽Ǥ");
  */
 int mon_damage_mod(monster_type *m_ptr, int dam, int type)
 {
+	/* Unused */
+	(void)type;
+
 	if (m_ptr->invulner && !(randint1(PENETRATE_INVULNERABILITY) == 1))
 		return (0);
 	else
@@ -1449,14 +1454,17 @@ bool mon_take_hit(int m_idx, int dam, bool *fear, cptr note)
 		 */
 		if ((r_ptr->flags1 & RF1_UNIQUE) && take_notes && record_unique)
 		{
-			char note[80];
+			char note_buf[160];
 
 			/* Get true name even if blinded/hallucinating */
-			cptr monst = (r_name + r_ptr->name);
+#ifdef JP
+			sprintf(note_buf, "%s%s", r_name + r_ptr->name, (m_ptr->smart & SM_CLONED) ? "()" : "");
+#else
+			sprintf(note_buf, "%s%s", r_name + r_ptr->name, (m_ptr->smart & SM_CLONED) ? "(Clone)" : "");
+#endif
 
 			/* Write note */
-			sprintf(note, "%s", monst);
-			add_note(note, 'U');
+			add_note(note_buf, 'U');
 		}
 
 		/* Delete the monster */
@@ -1593,10 +1601,16 @@ void resize_map(void)
 
 	/* Hack -- update */
 	handle_stuff();
-	
+
 	/* Redraw */
 	Term_redraw();
 
+	/*
+	 * Waiting command;
+	 * Place the cursor on the player
+	 */
+	if (can_save) move_cursor_relative(py, px);
+
 	/* Refresh */
 	Term_fresh();
 }
@@ -2095,6 +2109,72 @@ static bool ang_sort_comp_distance(vptr u, vptr v, int a, int b)
 }
 
 
+/*
+ * Sorting hook -- comp function -- by importance level of grids
+ * Originally from Hengband
+ *
+ * We use "u" and "v" to point to arrays of "x" and "y" positions,
+ * and sort the arrays by level of monster
+ */
+static bool ang_sort_comp_importance(vptr u, vptr v, int a, int b)
+{
+	s16b *x = (s16b*)(u);
+	s16b *y = (s16b*)(v);
+	cave_type *ca_ptr = &cave[y[a]][x[a]];
+	cave_type *cb_ptr = &cave[y[b]][x[b]];
+	monster_type *ma_ptr = &m_list[ca_ptr->m_idx];
+	monster_type *mb_ptr = &m_list[cb_ptr->m_idx];
+	monster_race *ap_ra_ptr, *ap_rb_ptr;
+
+	/* The player grid */
+	if ((y[a] == py) && (x[a] == px)) return TRUE;
+	if ((y[b] == py) && (x[b] == px)) return FALSE;
+
+	/* Extract monster race */
+	if (ca_ptr->m_idx && ma_ptr->ml) ap_ra_ptr = &r_info[ma_ptr->r_idx];
+	else ap_ra_ptr = NULL;
+	if (cb_ptr->m_idx && mb_ptr->ml) ap_rb_ptr = &r_info[mb_ptr->r_idx];
+	else ap_rb_ptr = NULL;
+
+	if (ap_ra_ptr && !ap_rb_ptr) return TRUE;
+	if (!ap_ra_ptr && ap_rb_ptr) return FALSE;
+
+	/* Compare two monsters */
+	if (ap_ra_ptr && ap_rb_ptr)
+	{
+		/* Unique monsters first */
+		if ((ap_ra_ptr->flags1 & RF1_UNIQUE) && !(ap_rb_ptr->flags1 & RF1_UNIQUE)) return TRUE;
+		if (!(ap_ra_ptr->flags1 & RF1_UNIQUE) && (ap_rb_ptr->flags1 & RF1_UNIQUE)) return FALSE;
+
+ 		/* Unknown monsters first */
+		if (!ap_ra_ptr->r_tkills && ap_rb_ptr->r_tkills) return TRUE;
+		if (ap_ra_ptr->r_tkills && !ap_rb_ptr->r_tkills) return FALSE;
+
+		/* Higher level monsters first (if known) */
+		if (ap_ra_ptr->r_tkills && ap_rb_ptr->r_tkills)
+		{
+			if (ap_ra_ptr->level > ap_rb_ptr->level) return TRUE;
+			if (ap_ra_ptr->level < ap_rb_ptr->level) return FALSE;
+		}
+
+		/* Sort by index if all conditions are same */
+		if (ma_ptr->r_idx > mb_ptr->r_idx) return TRUE;
+		if (ma_ptr->r_idx < mb_ptr->r_idx) return FALSE;
+	}
+
+	/* An object get higher priority */
+	if (cave[y[a]][x[a]].o_idx && !cave[y[b]][x[b]].o_idx) return TRUE;
+	if (!cave[y[a]][x[a]].o_idx && cave[y[b]][x[b]].o_idx) return FALSE;
+
+	/* Priority from the terrain */
+	if (f_info[ca_ptr->feat].priority > f_info[cb_ptr->feat].priority) return TRUE;
+	if (f_info[ca_ptr->feat].priority < f_info[cb_ptr->feat].priority) return FALSE;
+
+	/* If all conditions are same, compare distance */
+	return ang_sort_comp_distance(u, v, a, b);
+}
+
+
 /*
  * Sorting hook -- swap function -- by "distance to player"
  *
@@ -2180,7 +2260,7 @@ static bool target_set_accept(int y, int x)
 {
 	cave_type *c_ptr;
 
-	s16b this_o_idx, next_o_idx = 0;
+	s16b this_o_idx, next_o_idx;
 
 	/* Bounds */
 	if (!(in_bounds(y, x))) return (FALSE);
@@ -2217,7 +2297,7 @@ static bool target_set_accept(int y, int x)
 		next_o_idx = o_ptr->next_o_idx;
 
 		/* Memorized object */
-		if (o_ptr->marked) return (TRUE);
+		if (o_ptr->marked & OM_FOUND) return (TRUE);
 	}
 
 	/* Interesting memorized features */
@@ -2330,8 +2410,18 @@ static void target_set_prepare(int mode)
 	}
 
 	/* Set the sort hooks */
-	ang_sort_comp = ang_sort_comp_distance;
-	ang_sort_swap = ang_sort_swap_distance;
+	if (mode & TARGET_KILL)
+	{
+		/* Target the nearest monster for shooting */
+		ang_sort_comp = ang_sort_comp_distance;
+		ang_sort_swap = ang_sort_swap_distance;
+	}
+	else
+	{
+		/* Look important grids first in Look command */
+		ang_sort_comp = ang_sort_comp_importance;
+		ang_sort_swap = ang_sort_swap_distance;
+	}
 
 	/* Sort the positions */
 	ang_sort(temp_x, temp_y, temp_n);
@@ -2384,6 +2474,8 @@ static void evaluate_monster_exp(char *acount, monster_type *m_ptr)
 }
 
 
+bool show_gold_on_floor = FALSE;
+
 /*
  * Examine a grid, return a keypress.
  *
@@ -2408,7 +2500,7 @@ static void evaluate_monster_exp(char *acount, monster_type *m_ptr)
 static int target_set_aux(int y, int x, int mode, cptr info)
 {
 	cave_type *c_ptr = &cave[y][x];
-	s16b this_o_idx, next_o_idx = 0;
+	s16b this_o_idx, next_o_idx;
 	cptr x_info = "";
 	bool boring;
 	int feat;
@@ -2623,7 +2715,7 @@ static int target_set_aux(int y, int x, int mode, cptr info)
 					next_o_idx = o_ptr->next_o_idx;
 
 					/* Obtain an object description */
-					object_desc(o_name, o_ptr, TRUE, 3);
+					object_desc(o_name, o_ptr, 0);
 
 					/* Describe the object */
 #ifdef JP
@@ -2668,9 +2760,6 @@ static int target_set_aux(int y, int x, int mode, cptr info)
 		{
 			char comkey = rogue_like_commands ? 'x' : 'l';
 
-			/* Not boring */
-			boring = FALSE;
-
 			while (1)
 			{
 				if (floor_num == 1)
@@ -2683,7 +2772,7 @@ static int target_set_aux(int y, int x, int mode, cptr info)
 					o_ptr = &o_list[floor_list[0]];
 
 					/* Describe the object */
-					object_desc(o_name, o_ptr, TRUE, 3);
+					object_desc(o_name, o_ptr, 0);
 
 					/* Message */
 #ifdef JP
@@ -2723,7 +2812,9 @@ static int target_set_aux(int y, int x, int mode, cptr info)
 					screen_save();
 
 					/* Display */
+					show_gold_on_floor = TRUE;
 					show_floor(y, x);
+					show_gold_on_floor = FALSE;
 
 					/* Prompt */
 #ifdef JP
@@ -2769,7 +2860,7 @@ static int target_set_aux(int y, int x, int mode, cptr info)
 				if (query != '\n' && query != '\r') break;
 			}
 
-			/* Stop */
+			/* Stop - not boring */
 			break;
 		}
 
@@ -2788,7 +2879,7 @@ static int target_set_aux(int y, int x, int mode, cptr info)
 			next_o_idx = o_ptr->next_o_idx;
 
 			/* Describe it */
-			if (o_ptr->marked)
+			if (o_ptr->marked & OM_FOUND)
 			{
 				char o_name[MAX_NLEN];
 
@@ -2796,7 +2887,7 @@ static int target_set_aux(int y, int x, int mode, cptr info)
 				boring = FALSE;
 
 				/* Obtain an object description */
-				object_desc(o_name, o_ptr, TRUE, 3);
+				object_desc(o_name, o_ptr, 0);
 
 				/* Describe the object */
 #ifdef JP
@@ -2884,10 +2975,11 @@ static int target_set_aux(int y, int x, int mode, cptr info)
 				quest_text_line = 0;
 #ifdef JP
 				process_dungeon_file("q_info_j.txt", 0, 0, 0, 0);
+				name = format("ȡ%s(%d)", quest[c_ptr->special].name, quest[c_ptr->special].level);
 #else
 				process_dungeon_file("q_info.txt", 0, 0, 0, 0);
+				name = format("quest '%s'(level %d)", quest[c_ptr->special].name, quest[c_ptr->special].level);
 #endif
-				name = quest[c_ptr->special].name;
 
 				/* Reset the old quest number */
 				p_ptr->inside_quest = old_quest;
@@ -2922,20 +3014,13 @@ static int target_set_aux(int y, int x, int mode, cptr info)
 
 			/* Hack -- special introduction for store & building doors -KMW- */
 			if (((feat >= FEAT_SHOP_HEAD) && (feat <= FEAT_SHOP_TAIL)) ||
-			    ((feat >= FEAT_BLDG_HEAD) && (feat <= FEAT_BLDG_TAIL)))
+			    ((feat >= FEAT_BLDG_HEAD) && (feat <= FEAT_BLDG_TAIL)) ||
+			     (feat == FEAT_QUEST_ENTER))
 			{
 #ifdef JP
 				s2 = "";
 #else
 				s3 = "the entrance to the ";
-#endif
-			}
-			else if (feat == FEAT_QUEST_ENTER)
-			{
-#ifdef JP
-				s3 = "Υ";
-#else
-				s3 = "the quest-entrance to the ";
 #endif
 			}
 			else if ((feat == FEAT_FLOOR) || (feat == FEAT_DIRT))
@@ -3037,10 +3122,8 @@ bool target_set(int mode)
 
 	cave_type		*c_ptr;
 
-#ifdef JP
 	/* XTRA HACK MOVEFAST */
 	bool    move_fast;
-#endif
 
 	int wid, hgt;
 
@@ -3104,10 +3187,7 @@ strcpy(info, "q p o + -");
 
 			/* Assume no "direction" */
 			d = 0;
-#ifdef JP
-			/* XTRA HACK MOVEFAST */
-			move_fast = FALSE;
-#endif
+
 			/* Analyze */
 			switch (query)
 			{
@@ -3311,9 +3391,6 @@ strcpy(info, "q p o + -");
 		{
 			if (!(mode & TARGET_LOOK)) prt_path(y, x);
 
-			/* Access */
-			c_ptr = &cave[y][x];
-
 			/* Default prompt */
 #ifdef JP
 strcpy(info, "q t p m + -");
@@ -3324,10 +3401,9 @@ strcpy(info, "q t p m + -");
 
 			/* Describe and Prompt (enable "TARGET_LOOK") */
 			query = target_set_aux(y, x, mode | TARGET_LOOK, info);
-#ifdef JP
+
 			/* XTRA HACK MOVEFAST */
 			move_fast = FALSE;
-#endif
 
 			/* Cancel tracking */
 			/* health_track(0); */
@@ -3420,10 +3496,10 @@ strcpy(info, "q t p m + -");
 				{
 					/* Extract the action (if any) */
 					d = get_keymap_dir(query);
-#ifdef JP
+
 					/* XTRA HACK MOVEFAST */
 					if (isupper(query)) move_fast = TRUE;
-#endif
+
 					if (!d) bell();
 					break;
 				}
@@ -3435,21 +3511,19 @@ strcpy(info, "q t p m + -");
 				int dx = ddx[d];
 				int dy = ddy[d];
 
-#ifdef JP
 				/* XTRA HACK MOVEFAST */
+				/* Move */
 				if (move_fast)
 				{
 					x += dx * wid / 2;
 					y += dy * hgt / 2;
-				} else {
+				}
+				else
+				{
 					x += dx;
 					y += dy;
 				}
-#else
-				/* Move */
-				x += dx;
-				y += dy;
-#endif
+
 				/* Do not move horizontally if unnecessary */
 				if (((x < panel_col_min + wid / 2) && (dx > 0)) ||
 					 ((x > panel_col_min + wid / 2) && (dx < 0)))
